Documentation
¶
Index ¶
- Constants
- Variables
- func MakeBadRequest(err error) *goa.ServiceError
- func MakeConflict(err error) *goa.ServiceError
- func MakeForbidden(err error) *goa.ServiceError
- func MakeGatewayError(err error) *goa.ServiceError
- func MakeInvalid(err error) *goa.ServiceError
- func MakeInvariantViolation(err error) *goa.ServiceError
- func MakeNotFound(err error) *goa.ServiceError
- func MakeUnauthorized(err error) *goa.ServiceError
- func MakeUnexpected(err error) *goa.ServiceError
- func MakeUnsupportedMedia(err error) *goa.ServiceError
- func NewOpenapiEndpoint(s Service) goa.Endpoint
- type Client
- type Endpoints
- type OpenapiResponseData
- type OpenapiResult
- type Service
Constants ¶
const APIName = "gram"
APIName is the name of the API as defined in the design.
const APIVersion = "0.0.1"
APIVersion is the version of the API as defined in the design.
const ServiceName = "about"
ServiceName is the name of the service as defined in the design. This is the same value that is set in the endpoint request contexts under the ServiceKey key.
Variables ¶
var MethodNames = [1]string{"openapi"}
MethodNames lists the service method names as defined in the design. These are the same values that are set in the endpoint request contexts under the MethodKey key.
Functions ¶
func MakeBadRequest ¶
func MakeBadRequest(err error) *goa.ServiceError
MakeBadRequest builds a goa.ServiceError from an error.
func MakeConflict ¶
func MakeConflict(err error) *goa.ServiceError
MakeConflict builds a goa.ServiceError from an error.
func MakeForbidden ¶
func MakeForbidden(err error) *goa.ServiceError
MakeForbidden builds a goa.ServiceError from an error.
func MakeGatewayError ¶
func MakeGatewayError(err error) *goa.ServiceError
MakeGatewayError builds a goa.ServiceError from an error.
func MakeInvalid ¶
func MakeInvalid(err error) *goa.ServiceError
MakeInvalid builds a goa.ServiceError from an error.
func MakeInvariantViolation ¶
func MakeInvariantViolation(err error) *goa.ServiceError
MakeInvariantViolation builds a goa.ServiceError from an error.
func MakeNotFound ¶
func MakeNotFound(err error) *goa.ServiceError
MakeNotFound builds a goa.ServiceError from an error.
func MakeUnauthorized ¶
func MakeUnauthorized(err error) *goa.ServiceError
MakeUnauthorized builds a goa.ServiceError from an error.
func MakeUnexpected ¶
func MakeUnexpected(err error) *goa.ServiceError
MakeUnexpected builds a goa.ServiceError from an error.
func MakeUnsupportedMedia ¶
func MakeUnsupportedMedia(err error) *goa.ServiceError
MakeUnsupportedMedia builds a goa.ServiceError from an error.
func NewOpenapiEndpoint ¶
NewOpenapiEndpoint returns an endpoint function that calls the method "openapi" of service "about".
Types ¶
type Client ¶
Client is the "about" service client.
func (*Client) Openapi ¶
func (c *Client) Openapi(ctx context.Context) (res *OpenapiResult, resp io.ReadCloser, err error)
Openapi calls the "openapi" endpoint of the "about" service. Openapi may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
type Endpoints ¶
Endpoints wraps the "about" service endpoints.
func NewEndpoints ¶
NewEndpoints wraps the methods of the "about" service with endpoints.
type OpenapiResponseData ¶
type OpenapiResponseData struct {
// Result is the method result.
Result *OpenapiResult
// Body streams the HTTP response body.
Body io.ReadCloser
}
OpenapiResponseData holds both the result and the HTTP response body reader of the "openapi" method.
type OpenapiResult ¶
type OpenapiResult struct {
// The content type of the OpenAPI document
ContentType string
// The content length of the OpenAPI document
ContentLength int64
}
OpenapiResult is the result type of the about service openapi method.
type Service ¶
type Service interface {
// If body implements [io.WriterTo], that implementation will be used instead.
// Consider [goa.design/goa/v3/pkg.SkipResponseWriter] to adapt existing
// implementations.
Openapi(context.Context) (res *OpenapiResult, body io.ReadCloser, err error)
}
Information about the Gram platform and its components.