features

package
v0.0.0-...-7f732e0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const APIName = "gram"

APIName is the name of the API as defined in the design.

const APIVersion = "0.0.1"

APIVersion is the version of the API as defined in the design.

const ServiceName = "features"

ServiceName is the name of the service as defined in the design. This is the same value that is set in the endpoint request contexts under the ServiceKey key.

Variables

var MethodNames = [2]string{"getProductFeatures", "setProductFeature"}

MethodNames lists the service method names as defined in the design. These are the same values that are set in the endpoint request contexts under the MethodKey key.

Functions

func MakeBadRequest

func MakeBadRequest(err error) *goa.ServiceError

MakeBadRequest builds a goa.ServiceError from an error.

func MakeConflict

func MakeConflict(err error) *goa.ServiceError

MakeConflict builds a goa.ServiceError from an error.

func MakeForbidden

func MakeForbidden(err error) *goa.ServiceError

MakeForbidden builds a goa.ServiceError from an error.

func MakeGatewayError

func MakeGatewayError(err error) *goa.ServiceError

MakeGatewayError builds a goa.ServiceError from an error.

func MakeInvalid

func MakeInvalid(err error) *goa.ServiceError

MakeInvalid builds a goa.ServiceError from an error.

func MakeInvariantViolation

func MakeInvariantViolation(err error) *goa.ServiceError

MakeInvariantViolation builds a goa.ServiceError from an error.

func MakeNotFound

func MakeNotFound(err error) *goa.ServiceError

MakeNotFound builds a goa.ServiceError from an error.

func MakeUnauthorized

func MakeUnauthorized(err error) *goa.ServiceError

MakeUnauthorized builds a goa.ServiceError from an error.

func MakeUnexpected

func MakeUnexpected(err error) *goa.ServiceError

MakeUnexpected builds a goa.ServiceError from an error.

func MakeUnsupportedMedia

func MakeUnsupportedMedia(err error) *goa.ServiceError

MakeUnsupportedMedia builds a goa.ServiceError from an error.

func NewGetProductFeaturesEndpoint

func NewGetProductFeaturesEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint

NewGetProductFeaturesEndpoint returns an endpoint function that calls the method "getProductFeatures" of service "features".

func NewSetProductFeatureEndpoint

func NewSetProductFeatureEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint

NewSetProductFeatureEndpoint returns an endpoint function that calls the method "setProductFeature" of service "features".

func NewViewedGramProductFeatures

func NewViewedGramProductFeatures(res *GramProductFeatures, view string) *featuresviews.GramProductFeatures

NewViewedGramProductFeatures initializes viewed result type GramProductFeatures from result type GramProductFeatures using the given view.

Types

type Auther

type Auther interface {
	// APIKeyAuth implements the authorization logic for the APIKey security scheme.
	APIKeyAuth(ctx context.Context, key string, schema *security.APIKeyScheme) (context.Context, error)
}

Auther defines the authorization functions to be implemented by the service.

type Client

type Client struct {
	GetProductFeaturesEndpoint goa.Endpoint
	SetProductFeatureEndpoint  goa.Endpoint
}

Client is the "features" service client.

func NewClient

func NewClient(getProductFeatures, setProductFeature goa.Endpoint) *Client

NewClient initializes a "features" service client given the endpoints.

func (*Client) GetProductFeatures

func (c *Client) GetProductFeatures(ctx context.Context, p *GetProductFeaturesPayload) (res *GramProductFeatures, err error)

GetProductFeatures calls the "getProductFeatures" endpoint of the "features" service. GetProductFeatures may return the following errors:

  • "unauthorized" (type *goa.ServiceError): unauthorized access
  • "forbidden" (type *goa.ServiceError): permission denied
  • "bad_request" (type *goa.ServiceError): request is invalid
  • "not_found" (type *goa.ServiceError): resource not found
  • "conflict" (type *goa.ServiceError): resource already exists
  • "unsupported_media" (type *goa.ServiceError): unsupported media type
  • "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
  • "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
  • "unexpected" (type *goa.ServiceError): an unexpected error occurred
  • "gateway_error" (type *goa.ServiceError): an unexpected error occurred
  • error: internal error

func (*Client) SetProductFeature

func (c *Client) SetProductFeature(ctx context.Context, p *SetProductFeaturePayload) (err error)

SetProductFeature calls the "setProductFeature" endpoint of the "features" service. SetProductFeature may return the following errors:

  • "unauthorized" (type *goa.ServiceError): unauthorized access
  • "forbidden" (type *goa.ServiceError): permission denied
  • "bad_request" (type *goa.ServiceError): request is invalid
  • "not_found" (type *goa.ServiceError): resource not found
  • "conflict" (type *goa.ServiceError): resource already exists
  • "unsupported_media" (type *goa.ServiceError): unsupported media type
  • "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
  • "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
  • "unexpected" (type *goa.ServiceError): an unexpected error occurred
  • "gateway_error" (type *goa.ServiceError): an unexpected error occurred
  • error: internal error

type Endpoints

type Endpoints struct {
	GetProductFeatures goa.Endpoint
	SetProductFeature  goa.Endpoint
}

Endpoints wraps the "features" service endpoints.

func NewEndpoints

func NewEndpoints(s Service) *Endpoints

NewEndpoints wraps the methods of the "features" service with endpoints.

func (*Endpoints) Use

func (e *Endpoints) Use(m func(goa.Endpoint) goa.Endpoint)

Use applies the given middleware to all the "features" service endpoints.

type GetProductFeaturesPayload

type GetProductFeaturesPayload struct {
	SessionToken *string
}

GetProductFeaturesPayload is the payload type of the features service getProductFeatures method.

type GramProductFeatures

type GramProductFeatures struct {
	// Whether logging is enabled
	LogsEnabled bool
	// Whether tool I/O logging is enabled
	ToolIoLogsEnabled bool
	// Whether Claude Code session capture is enabled
	SessionCaptureEnabled bool
	// Whether authz challenge logging to ClickHouse is enabled
	AuthzChallengeLoggingEnabled bool
}

GramProductFeatures is the result type of the features service getProductFeatures method.

func NewGramProductFeatures

func NewGramProductFeatures(vres *featuresviews.GramProductFeatures) *GramProductFeatures

NewGramProductFeatures initializes result type GramProductFeatures from viewed result type GramProductFeatures.

type Service

type Service interface {
	// Get the current state of all product feature flags.
	GetProductFeatures(context.Context, *GetProductFeaturesPayload) (res *GramProductFeatures, err error)
	// Enable or disable an organization feature flag.
	SetProductFeature(context.Context, *SetProductFeaturePayload) (err error)
}

Manage product level feature controls.

type SetProductFeaturePayload

type SetProductFeaturePayload struct {
	// Name of the feature to update
	FeatureName string
	// Whether the feature should be enabled
	Enabled      bool
	SessionToken *string
}

SetProductFeaturePayload is the payload type of the features service setProductFeature method.

Directories

Path Synopsis

Jump to