views

package
v0.0.0-...-3517705 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: AGPL-3.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// GramProductFeaturesMap is a map indexing the attribute names of
	// GramProductFeatures by view name.
	GramProductFeaturesMap = map[string][]string{
		"default": {
			"logs_enabled",
			"tool_io_logs_enabled",
			"session_capture_enabled",
			"authz_challenge_logging_enabled",
		},
	}
)

Functions

func ValidateGramProductFeatures

func ValidateGramProductFeatures(result *GramProductFeatures) (err error)

ValidateGramProductFeatures runs the validations defined on the viewed result type GramProductFeatures.

func ValidateGramProductFeaturesView

func ValidateGramProductFeaturesView(result *GramProductFeaturesView) (err error)

ValidateGramProductFeaturesView runs the validations defined on GramProductFeaturesView using the "default" view.

Types

type GramProductFeatures

type GramProductFeatures struct {
	// Type to project
	Projected *GramProductFeaturesView
	// View to render
	View string
}

GramProductFeatures is the viewed result type that is projected based on a view.

type GramProductFeaturesView

type GramProductFeaturesView struct {
	// Whether logging is enabled
	LogsEnabled *bool
	// Whether tool I/O logging is enabled
	ToolIoLogsEnabled *bool
	// Whether Claude Code session capture is enabled
	SessionCaptureEnabled *bool
	// Whether authz challenge logging to ClickHouse is enabled
	AuthzChallengeLoggingEnabled *bool
}

GramProductFeaturesView is a type that runs validations on a projected type.

Jump to