client

package
v0.0.0-...-4ae6852 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2025 License: AGPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildCreditUsagePayload

func BuildCreditUsagePayload(chatCreditUsageSessionToken string, chatCreditUsageProjectSlugInput string) (*chat.CreditUsagePayload, error)

BuildCreditUsagePayload builds the payload for the chat creditUsage endpoint from CLI flags.

func BuildListChatsPayload

func BuildListChatsPayload(chatListChatsSessionToken string, chatListChatsProjectSlugInput string) (*chat.ListChatsPayload, error)

BuildListChatsPayload builds the payload for the chat listChats endpoint from CLI flags.

func BuildLoadChatPayload

func BuildLoadChatPayload(chatLoadChatID string, chatLoadChatSessionToken string, chatLoadChatProjectSlugInput string) (*chat.LoadChatPayload, error)

BuildLoadChatPayload builds the payload for the chat loadChat endpoint from CLI flags.

func CreditUsageChatPath

func CreditUsageChatPath() string

CreditUsageChatPath returns the URL path to the chat service creditUsage HTTP endpoint.

func DecodeCreditUsageResponse

func DecodeCreditUsageResponse(decoder func(*http.Response) goahttp.Decoder, restoreBody bool) func(*http.Response) (any, error)

DecodeCreditUsageResponse returns a decoder for responses returned by the chat creditUsage endpoint. restoreBody controls whether the response body should be restored after having been read. DecodeCreditUsageResponse may return the following errors:

  • "unauthorized" (type *goa.ServiceError): http.StatusUnauthorized
  • "forbidden" (type *goa.ServiceError): http.StatusForbidden
  • "bad_request" (type *goa.ServiceError): http.StatusBadRequest
  • "not_found" (type *goa.ServiceError): http.StatusNotFound
  • "conflict" (type *goa.ServiceError): http.StatusConflict
  • "unsupported_media" (type *goa.ServiceError): http.StatusUnsupportedMediaType
  • "invalid" (type *goa.ServiceError): http.StatusUnprocessableEntity
  • "invariant_violation" (type *goa.ServiceError): http.StatusInternalServerError
  • "unexpected" (type *goa.ServiceError): http.StatusInternalServerError
  • "gateway_error" (type *goa.ServiceError): http.StatusBadGateway
  • error: internal error

func DecodeListChatsResponse

func DecodeListChatsResponse(decoder func(*http.Response) goahttp.Decoder, restoreBody bool) func(*http.Response) (any, error)

DecodeListChatsResponse returns a decoder for responses returned by the chat listChats endpoint. restoreBody controls whether the response body should be restored after having been read. DecodeListChatsResponse may return the following errors:

  • "unauthorized" (type *goa.ServiceError): http.StatusUnauthorized
  • "forbidden" (type *goa.ServiceError): http.StatusForbidden
  • "bad_request" (type *goa.ServiceError): http.StatusBadRequest
  • "not_found" (type *goa.ServiceError): http.StatusNotFound
  • "conflict" (type *goa.ServiceError): http.StatusConflict
  • "unsupported_media" (type *goa.ServiceError): http.StatusUnsupportedMediaType
  • "invalid" (type *goa.ServiceError): http.StatusUnprocessableEntity
  • "invariant_violation" (type *goa.ServiceError): http.StatusInternalServerError
  • "unexpected" (type *goa.ServiceError): http.StatusInternalServerError
  • "gateway_error" (type *goa.ServiceError): http.StatusBadGateway
  • error: internal error

func DecodeLoadChatResponse

func DecodeLoadChatResponse(decoder func(*http.Response) goahttp.Decoder, restoreBody bool) func(*http.Response) (any, error)

DecodeLoadChatResponse returns a decoder for responses returned by the chat loadChat endpoint. restoreBody controls whether the response body should be restored after having been read. DecodeLoadChatResponse may return the following errors:

  • "unauthorized" (type *goa.ServiceError): http.StatusUnauthorized
  • "forbidden" (type *goa.ServiceError): http.StatusForbidden
  • "bad_request" (type *goa.ServiceError): http.StatusBadRequest
  • "not_found" (type *goa.ServiceError): http.StatusNotFound
  • "conflict" (type *goa.ServiceError): http.StatusConflict
  • "unsupported_media" (type *goa.ServiceError): http.StatusUnsupportedMediaType
  • "invalid" (type *goa.ServiceError): http.StatusUnprocessableEntity
  • "invariant_violation" (type *goa.ServiceError): http.StatusInternalServerError
  • "unexpected" (type *goa.ServiceError): http.StatusInternalServerError
  • "gateway_error" (type *goa.ServiceError): http.StatusBadGateway
  • error: internal error

func EncodeCreditUsageRequest

func EncodeCreditUsageRequest(encoder func(*http.Request) goahttp.Encoder) func(*http.Request, any) error

EncodeCreditUsageRequest returns an encoder for requests sent to the chat creditUsage server.

func EncodeListChatsRequest

func EncodeListChatsRequest(encoder func(*http.Request) goahttp.Encoder) func(*http.Request, any) error

EncodeListChatsRequest returns an encoder for requests sent to the chat listChats server.

func EncodeLoadChatRequest

func EncodeLoadChatRequest(encoder func(*http.Request) goahttp.Encoder) func(*http.Request, any) error

EncodeLoadChatRequest returns an encoder for requests sent to the chat loadChat server.

func ListChatsChatPath

func ListChatsChatPath() string

ListChatsChatPath returns the URL path to the chat service listChats HTTP endpoint.

func LoadChatChatPath

func LoadChatChatPath() string

LoadChatChatPath returns the URL path to the chat service loadChat HTTP endpoint.

func NewCreditUsageBadRequest

func NewCreditUsageBadRequest(body *CreditUsageBadRequestResponseBody) *goa.ServiceError

NewCreditUsageBadRequest builds a chat service creditUsage endpoint bad_request error.

func NewCreditUsageConflict

func NewCreditUsageConflict(body *CreditUsageConflictResponseBody) *goa.ServiceError

NewCreditUsageConflict builds a chat service creditUsage endpoint conflict error.

func NewCreditUsageForbidden

func NewCreditUsageForbidden(body *CreditUsageForbiddenResponseBody) *goa.ServiceError

NewCreditUsageForbidden builds a chat service creditUsage endpoint forbidden error.

func NewCreditUsageGatewayError

func NewCreditUsageGatewayError(body *CreditUsageGatewayErrorResponseBody) *goa.ServiceError

NewCreditUsageGatewayError builds a chat service creditUsage endpoint gateway_error error.

func NewCreditUsageInvalid

func NewCreditUsageInvalid(body *CreditUsageInvalidResponseBody) *goa.ServiceError

NewCreditUsageInvalid builds a chat service creditUsage endpoint invalid error.

func NewCreditUsageInvariantViolation

func NewCreditUsageInvariantViolation(body *CreditUsageInvariantViolationResponseBody) *goa.ServiceError

NewCreditUsageInvariantViolation builds a chat service creditUsage endpoint invariant_violation error.

func NewCreditUsageNotFound

func NewCreditUsageNotFound(body *CreditUsageNotFoundResponseBody) *goa.ServiceError

NewCreditUsageNotFound builds a chat service creditUsage endpoint not_found error.

func NewCreditUsageResultOK

func NewCreditUsageResultOK(body *CreditUsageResponseBody) *chat.CreditUsageResult

NewCreditUsageResultOK builds a "chat" service "creditUsage" endpoint result from a HTTP "OK" response.

func NewCreditUsageUnauthorized

func NewCreditUsageUnauthorized(body *CreditUsageUnauthorizedResponseBody) *goa.ServiceError

NewCreditUsageUnauthorized builds a chat service creditUsage endpoint unauthorized error.

func NewCreditUsageUnexpected

func NewCreditUsageUnexpected(body *CreditUsageUnexpectedResponseBody) *goa.ServiceError

NewCreditUsageUnexpected builds a chat service creditUsage endpoint unexpected error.

func NewCreditUsageUnsupportedMedia

func NewCreditUsageUnsupportedMedia(body *CreditUsageUnsupportedMediaResponseBody) *goa.ServiceError

NewCreditUsageUnsupportedMedia builds a chat service creditUsage endpoint unsupported_media error.

func NewListChatsBadRequest

func NewListChatsBadRequest(body *ListChatsBadRequestResponseBody) *goa.ServiceError

NewListChatsBadRequest builds a chat service listChats endpoint bad_request error.

func NewListChatsConflict

func NewListChatsConflict(body *ListChatsConflictResponseBody) *goa.ServiceError

NewListChatsConflict builds a chat service listChats endpoint conflict error.

func NewListChatsForbidden

func NewListChatsForbidden(body *ListChatsForbiddenResponseBody) *goa.ServiceError

NewListChatsForbidden builds a chat service listChats endpoint forbidden error.

func NewListChatsGatewayError

func NewListChatsGatewayError(body *ListChatsGatewayErrorResponseBody) *goa.ServiceError

NewListChatsGatewayError builds a chat service listChats endpoint gateway_error error.

func NewListChatsInvalid

func NewListChatsInvalid(body *ListChatsInvalidResponseBody) *goa.ServiceError

NewListChatsInvalid builds a chat service listChats endpoint invalid error.

func NewListChatsInvariantViolation

func NewListChatsInvariantViolation(body *ListChatsInvariantViolationResponseBody) *goa.ServiceError

NewListChatsInvariantViolation builds a chat service listChats endpoint invariant_violation error.

func NewListChatsNotFound

func NewListChatsNotFound(body *ListChatsNotFoundResponseBody) *goa.ServiceError

NewListChatsNotFound builds a chat service listChats endpoint not_found error.

func NewListChatsResultOK

func NewListChatsResultOK(body *ListChatsResponseBody) *chat.ListChatsResult

NewListChatsResultOK builds a "chat" service "listChats" endpoint result from a HTTP "OK" response.

func NewListChatsUnauthorized

func NewListChatsUnauthorized(body *ListChatsUnauthorizedResponseBody) *goa.ServiceError

NewListChatsUnauthorized builds a chat service listChats endpoint unauthorized error.

func NewListChatsUnexpected

func NewListChatsUnexpected(body *ListChatsUnexpectedResponseBody) *goa.ServiceError

NewListChatsUnexpected builds a chat service listChats endpoint unexpected error.

func NewListChatsUnsupportedMedia

func NewListChatsUnsupportedMedia(body *ListChatsUnsupportedMediaResponseBody) *goa.ServiceError

NewListChatsUnsupportedMedia builds a chat service listChats endpoint unsupported_media error.

func NewLoadChatBadRequest

func NewLoadChatBadRequest(body *LoadChatBadRequestResponseBody) *goa.ServiceError

NewLoadChatBadRequest builds a chat service loadChat endpoint bad_request error.

func NewLoadChatChatOK

func NewLoadChatChatOK(body *LoadChatResponseBody) *chat.Chat

NewLoadChatChatOK builds a "chat" service "loadChat" endpoint result from a HTTP "OK" response.

func NewLoadChatConflict

func NewLoadChatConflict(body *LoadChatConflictResponseBody) *goa.ServiceError

NewLoadChatConflict builds a chat service loadChat endpoint conflict error.

func NewLoadChatForbidden

func NewLoadChatForbidden(body *LoadChatForbiddenResponseBody) *goa.ServiceError

NewLoadChatForbidden builds a chat service loadChat endpoint forbidden error.

func NewLoadChatGatewayError

func NewLoadChatGatewayError(body *LoadChatGatewayErrorResponseBody) *goa.ServiceError

NewLoadChatGatewayError builds a chat service loadChat endpoint gateway_error error.

func NewLoadChatInvalid

func NewLoadChatInvalid(body *LoadChatInvalidResponseBody) *goa.ServiceError

NewLoadChatInvalid builds a chat service loadChat endpoint invalid error.

func NewLoadChatInvariantViolation

func NewLoadChatInvariantViolation(body *LoadChatInvariantViolationResponseBody) *goa.ServiceError

NewLoadChatInvariantViolation builds a chat service loadChat endpoint invariant_violation error.

func NewLoadChatNotFound

func NewLoadChatNotFound(body *LoadChatNotFoundResponseBody) *goa.ServiceError

NewLoadChatNotFound builds a chat service loadChat endpoint not_found error.

func NewLoadChatUnauthorized

func NewLoadChatUnauthorized(body *LoadChatUnauthorizedResponseBody) *goa.ServiceError

NewLoadChatUnauthorized builds a chat service loadChat endpoint unauthorized error.

func NewLoadChatUnexpected

func NewLoadChatUnexpected(body *LoadChatUnexpectedResponseBody) *goa.ServiceError

NewLoadChatUnexpected builds a chat service loadChat endpoint unexpected error.

func NewLoadChatUnsupportedMedia

func NewLoadChatUnsupportedMedia(body *LoadChatUnsupportedMediaResponseBody) *goa.ServiceError

NewLoadChatUnsupportedMedia builds a chat service loadChat endpoint unsupported_media error.

func ValidateChatMessageResponseBody

func ValidateChatMessageResponseBody(body *ChatMessageResponseBody) (err error)

ValidateChatMessageResponseBody runs the validations defined on ChatMessageResponseBody

func ValidateChatOverviewResponseBody

func ValidateChatOverviewResponseBody(body *ChatOverviewResponseBody) (err error)

ValidateChatOverviewResponseBody runs the validations defined on ChatOverviewResponseBody

func ValidateCreditUsageBadRequestResponseBody

func ValidateCreditUsageBadRequestResponseBody(body *CreditUsageBadRequestResponseBody) (err error)

ValidateCreditUsageBadRequestResponseBody runs the validations defined on creditUsage_bad_request_response_body

func ValidateCreditUsageConflictResponseBody

func ValidateCreditUsageConflictResponseBody(body *CreditUsageConflictResponseBody) (err error)

ValidateCreditUsageConflictResponseBody runs the validations defined on creditUsage_conflict_response_body

func ValidateCreditUsageForbiddenResponseBody

func ValidateCreditUsageForbiddenResponseBody(body *CreditUsageForbiddenResponseBody) (err error)

ValidateCreditUsageForbiddenResponseBody runs the validations defined on creditUsage_forbidden_response_body

func ValidateCreditUsageGatewayErrorResponseBody

func ValidateCreditUsageGatewayErrorResponseBody(body *CreditUsageGatewayErrorResponseBody) (err error)

ValidateCreditUsageGatewayErrorResponseBody runs the validations defined on creditUsage_gateway_error_response_body

func ValidateCreditUsageInvalidResponseBody

func ValidateCreditUsageInvalidResponseBody(body *CreditUsageInvalidResponseBody) (err error)

ValidateCreditUsageInvalidResponseBody runs the validations defined on creditUsage_invalid_response_body

func ValidateCreditUsageInvariantViolationResponseBody

func ValidateCreditUsageInvariantViolationResponseBody(body *CreditUsageInvariantViolationResponseBody) (err error)

ValidateCreditUsageInvariantViolationResponseBody runs the validations defined on creditUsage_invariant_violation_response_body

func ValidateCreditUsageNotFoundResponseBody

func ValidateCreditUsageNotFoundResponseBody(body *CreditUsageNotFoundResponseBody) (err error)

ValidateCreditUsageNotFoundResponseBody runs the validations defined on creditUsage_not_found_response_body

func ValidateCreditUsageResponseBody

func ValidateCreditUsageResponseBody(body *CreditUsageResponseBody) (err error)

ValidateCreditUsageResponseBody runs the validations defined on CreditUsageResponseBody

func ValidateCreditUsageUnauthorizedResponseBody

func ValidateCreditUsageUnauthorizedResponseBody(body *CreditUsageUnauthorizedResponseBody) (err error)

ValidateCreditUsageUnauthorizedResponseBody runs the validations defined on creditUsage_unauthorized_response_body

func ValidateCreditUsageUnexpectedResponseBody

func ValidateCreditUsageUnexpectedResponseBody(body *CreditUsageUnexpectedResponseBody) (err error)

ValidateCreditUsageUnexpectedResponseBody runs the validations defined on creditUsage_unexpected_response_body

func ValidateCreditUsageUnsupportedMediaResponseBody

func ValidateCreditUsageUnsupportedMediaResponseBody(body *CreditUsageUnsupportedMediaResponseBody) (err error)

ValidateCreditUsageUnsupportedMediaResponseBody runs the validations defined on creditUsage_unsupported_media_response_body

func ValidateListChatsBadRequestResponseBody

func ValidateListChatsBadRequestResponseBody(body *ListChatsBadRequestResponseBody) (err error)

ValidateListChatsBadRequestResponseBody runs the validations defined on listChats_bad_request_response_body

func ValidateListChatsConflictResponseBody

func ValidateListChatsConflictResponseBody(body *ListChatsConflictResponseBody) (err error)

ValidateListChatsConflictResponseBody runs the validations defined on listChats_conflict_response_body

func ValidateListChatsForbiddenResponseBody

func ValidateListChatsForbiddenResponseBody(body *ListChatsForbiddenResponseBody) (err error)

ValidateListChatsForbiddenResponseBody runs the validations defined on listChats_forbidden_response_body

func ValidateListChatsGatewayErrorResponseBody

func ValidateListChatsGatewayErrorResponseBody(body *ListChatsGatewayErrorResponseBody) (err error)

ValidateListChatsGatewayErrorResponseBody runs the validations defined on listChats_gateway_error_response_body

func ValidateListChatsInvalidResponseBody

func ValidateListChatsInvalidResponseBody(body *ListChatsInvalidResponseBody) (err error)

ValidateListChatsInvalidResponseBody runs the validations defined on listChats_invalid_response_body

func ValidateListChatsInvariantViolationResponseBody

func ValidateListChatsInvariantViolationResponseBody(body *ListChatsInvariantViolationResponseBody) (err error)

ValidateListChatsInvariantViolationResponseBody runs the validations defined on listChats_invariant_violation_response_body

func ValidateListChatsNotFoundResponseBody

func ValidateListChatsNotFoundResponseBody(body *ListChatsNotFoundResponseBody) (err error)

ValidateListChatsNotFoundResponseBody runs the validations defined on listChats_not_found_response_body

func ValidateListChatsResponseBody

func ValidateListChatsResponseBody(body *ListChatsResponseBody) (err error)

ValidateListChatsResponseBody runs the validations defined on ListChatsResponseBody

func ValidateListChatsUnauthorizedResponseBody

func ValidateListChatsUnauthorizedResponseBody(body *ListChatsUnauthorizedResponseBody) (err error)

ValidateListChatsUnauthorizedResponseBody runs the validations defined on listChats_unauthorized_response_body

func ValidateListChatsUnexpectedResponseBody

func ValidateListChatsUnexpectedResponseBody(body *ListChatsUnexpectedResponseBody) (err error)

ValidateListChatsUnexpectedResponseBody runs the validations defined on listChats_unexpected_response_body

func ValidateListChatsUnsupportedMediaResponseBody

func ValidateListChatsUnsupportedMediaResponseBody(body *ListChatsUnsupportedMediaResponseBody) (err error)

ValidateListChatsUnsupportedMediaResponseBody runs the validations defined on listChats_unsupported_media_response_body

func ValidateLoadChatBadRequestResponseBody

func ValidateLoadChatBadRequestResponseBody(body *LoadChatBadRequestResponseBody) (err error)

ValidateLoadChatBadRequestResponseBody runs the validations defined on loadChat_bad_request_response_body

func ValidateLoadChatConflictResponseBody

func ValidateLoadChatConflictResponseBody(body *LoadChatConflictResponseBody) (err error)

ValidateLoadChatConflictResponseBody runs the validations defined on loadChat_conflict_response_body

func ValidateLoadChatForbiddenResponseBody

func ValidateLoadChatForbiddenResponseBody(body *LoadChatForbiddenResponseBody) (err error)

ValidateLoadChatForbiddenResponseBody runs the validations defined on loadChat_forbidden_response_body

func ValidateLoadChatGatewayErrorResponseBody

func ValidateLoadChatGatewayErrorResponseBody(body *LoadChatGatewayErrorResponseBody) (err error)

ValidateLoadChatGatewayErrorResponseBody runs the validations defined on loadChat_gateway_error_response_body

func ValidateLoadChatInvalidResponseBody

func ValidateLoadChatInvalidResponseBody(body *LoadChatInvalidResponseBody) (err error)

ValidateLoadChatInvalidResponseBody runs the validations defined on loadChat_invalid_response_body

func ValidateLoadChatInvariantViolationResponseBody

func ValidateLoadChatInvariantViolationResponseBody(body *LoadChatInvariantViolationResponseBody) (err error)

ValidateLoadChatInvariantViolationResponseBody runs the validations defined on loadChat_invariant_violation_response_body

func ValidateLoadChatNotFoundResponseBody

func ValidateLoadChatNotFoundResponseBody(body *LoadChatNotFoundResponseBody) (err error)

ValidateLoadChatNotFoundResponseBody runs the validations defined on loadChat_not_found_response_body

func ValidateLoadChatResponseBody

func ValidateLoadChatResponseBody(body *LoadChatResponseBody) (err error)

ValidateLoadChatResponseBody runs the validations defined on LoadChatResponseBody

func ValidateLoadChatUnauthorizedResponseBody

func ValidateLoadChatUnauthorizedResponseBody(body *LoadChatUnauthorizedResponseBody) (err error)

ValidateLoadChatUnauthorizedResponseBody runs the validations defined on loadChat_unauthorized_response_body

func ValidateLoadChatUnexpectedResponseBody

func ValidateLoadChatUnexpectedResponseBody(body *LoadChatUnexpectedResponseBody) (err error)

ValidateLoadChatUnexpectedResponseBody runs the validations defined on loadChat_unexpected_response_body

func ValidateLoadChatUnsupportedMediaResponseBody

func ValidateLoadChatUnsupportedMediaResponseBody(body *LoadChatUnsupportedMediaResponseBody) (err error)

ValidateLoadChatUnsupportedMediaResponseBody runs the validations defined on loadChat_unsupported_media_response_body

Types

type ChatMessageResponseBody

type ChatMessageResponseBody struct {
	// The ID of the message
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// The role of the message
	Role *string `form:"role,omitempty" json:"role,omitempty" xml:"role,omitempty"`
	// The content of the message
	Content *string `form:"content,omitempty" json:"content,omitempty" xml:"content,omitempty"`
	// The model that generated the message
	Model *string `form:"model,omitempty" json:"model,omitempty" xml:"model,omitempty"`
	// The tool call ID of the message
	ToolCallID *string `form:"tool_call_id,omitempty" json:"tool_call_id,omitempty" xml:"tool_call_id,omitempty"`
	// The tool calls in the message as a JSON blob
	ToolCalls *string `form:"tool_calls,omitempty" json:"tool_calls,omitempty" xml:"tool_calls,omitempty"`
	// The finish reason of the message
	FinishReason *string `form:"finish_reason,omitempty" json:"finish_reason,omitempty" xml:"finish_reason,omitempty"`
	// The ID of the user who created the message
	UserID *string `form:"user_id,omitempty" json:"user_id,omitempty" xml:"user_id,omitempty"`
	// When the message was created.
	CreatedAt *string `form:"created_at,omitempty" json:"created_at,omitempty" xml:"created_at,omitempty"`
}

ChatMessageResponseBody is used to define fields on response body types.

type ChatOverviewResponseBody

type ChatOverviewResponseBody struct {
	// The ID of the chat
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// The title of the chat
	Title *string `form:"title,omitempty" json:"title,omitempty" xml:"title,omitempty"`
	// The ID of the user who created the chat
	UserID *string `form:"user_id,omitempty" json:"user_id,omitempty" xml:"user_id,omitempty"`
	// The number of messages in the chat
	NumMessages *int `form:"num_messages,omitempty" json:"num_messages,omitempty" xml:"num_messages,omitempty"`
	// When the chat was created.
	CreatedAt *string `form:"created_at,omitempty" json:"created_at,omitempty" xml:"created_at,omitempty"`
	// When the chat was last updated.
	UpdatedAt *string `form:"updated_at,omitempty" json:"updated_at,omitempty" xml:"updated_at,omitempty"`
}

ChatOverviewResponseBody is used to define fields on response body types.

type Client

type Client struct {
	// ListChats Doer is the HTTP client used to make requests to the listChats
	// endpoint.
	ListChatsDoer goahttp.Doer

	// LoadChat Doer is the HTTP client used to make requests to the loadChat
	// endpoint.
	LoadChatDoer goahttp.Doer

	// CreditUsage Doer is the HTTP client used to make requests to the creditUsage
	// endpoint.
	CreditUsageDoer goahttp.Doer

	// RestoreResponseBody controls whether the response bodies are reset after
	// decoding so they can be read again.
	RestoreResponseBody bool
	// contains filtered or unexported fields
}

Client lists the chat service endpoint HTTP clients.

func NewClient

func NewClient(
	scheme string,
	host string,
	doer goahttp.Doer,
	enc func(*http.Request) goahttp.Encoder,
	dec func(*http.Response) goahttp.Decoder,
	restoreBody bool,
) *Client

NewClient instantiates HTTP clients for all the chat service servers.

func (*Client) BuildCreditUsageRequest

func (c *Client) BuildCreditUsageRequest(ctx context.Context, v any) (*http.Request, error)

BuildCreditUsageRequest instantiates a HTTP request object with method and path set to call the "chat" service "creditUsage" endpoint

func (*Client) BuildListChatsRequest

func (c *Client) BuildListChatsRequest(ctx context.Context, v any) (*http.Request, error)

BuildListChatsRequest instantiates a HTTP request object with method and path set to call the "chat" service "listChats" endpoint

func (*Client) BuildLoadChatRequest

func (c *Client) BuildLoadChatRequest(ctx context.Context, v any) (*http.Request, error)

BuildLoadChatRequest instantiates a HTTP request object with method and path set to call the "chat" service "loadChat" endpoint

func (*Client) CreditUsage

func (c *Client) CreditUsage() goa.Endpoint

CreditUsage returns an endpoint that makes HTTP requests to the chat service creditUsage server.

func (*Client) ListChats

func (c *Client) ListChats() goa.Endpoint

ListChats returns an endpoint that makes HTTP requests to the chat service listChats server.

func (*Client) LoadChat

func (c *Client) LoadChat() goa.Endpoint

LoadChat returns an endpoint that makes HTTP requests to the chat service loadChat server.

type CreditUsageBadRequestResponseBody

type CreditUsageBadRequestResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreditUsageBadRequestResponseBody is the type of the "chat" service "creditUsage" endpoint HTTP response body for the "bad_request" error.

type CreditUsageConflictResponseBody

type CreditUsageConflictResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreditUsageConflictResponseBody is the type of the "chat" service "creditUsage" endpoint HTTP response body for the "conflict" error.

type CreditUsageForbiddenResponseBody

type CreditUsageForbiddenResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreditUsageForbiddenResponseBody is the type of the "chat" service "creditUsage" endpoint HTTP response body for the "forbidden" error.

type CreditUsageGatewayErrorResponseBody

type CreditUsageGatewayErrorResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreditUsageGatewayErrorResponseBody is the type of the "chat" service "creditUsage" endpoint HTTP response body for the "gateway_error" error.

type CreditUsageInvalidResponseBody

type CreditUsageInvalidResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreditUsageInvalidResponseBody is the type of the "chat" service "creditUsage" endpoint HTTP response body for the "invalid" error.

type CreditUsageInvariantViolationResponseBody

type CreditUsageInvariantViolationResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreditUsageInvariantViolationResponseBody is the type of the "chat" service "creditUsage" endpoint HTTP response body for the "invariant_violation" error.

type CreditUsageNotFoundResponseBody

type CreditUsageNotFoundResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreditUsageNotFoundResponseBody is the type of the "chat" service "creditUsage" endpoint HTTP response body for the "not_found" error.

type CreditUsageResponseBody

type CreditUsageResponseBody struct {
	// The number of credits remaining
	CreditsUsed *float64 `form:"credits_used,omitempty" json:"credits_used,omitempty" xml:"credits_used,omitempty"`
	// The number of monthly credits
	MonthlyCredits *int `form:"monthly_credits,omitempty" json:"monthly_credits,omitempty" xml:"monthly_credits,omitempty"`
}

CreditUsageResponseBody is the type of the "chat" service "creditUsage" endpoint HTTP response body.

type CreditUsageUnauthorizedResponseBody

type CreditUsageUnauthorizedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreditUsageUnauthorizedResponseBody is the type of the "chat" service "creditUsage" endpoint HTTP response body for the "unauthorized" error.

type CreditUsageUnexpectedResponseBody

type CreditUsageUnexpectedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreditUsageUnexpectedResponseBody is the type of the "chat" service "creditUsage" endpoint HTTP response body for the "unexpected" error.

type CreditUsageUnsupportedMediaResponseBody

type CreditUsageUnsupportedMediaResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreditUsageUnsupportedMediaResponseBody is the type of the "chat" service "creditUsage" endpoint HTTP response body for the "unsupported_media" error.

type ListChatsBadRequestResponseBody

type ListChatsBadRequestResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListChatsBadRequestResponseBody is the type of the "chat" service "listChats" endpoint HTTP response body for the "bad_request" error.

type ListChatsConflictResponseBody

type ListChatsConflictResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListChatsConflictResponseBody is the type of the "chat" service "listChats" endpoint HTTP response body for the "conflict" error.

type ListChatsForbiddenResponseBody

type ListChatsForbiddenResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListChatsForbiddenResponseBody is the type of the "chat" service "listChats" endpoint HTTP response body for the "forbidden" error.

type ListChatsGatewayErrorResponseBody

type ListChatsGatewayErrorResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListChatsGatewayErrorResponseBody is the type of the "chat" service "listChats" endpoint HTTP response body for the "gateway_error" error.

type ListChatsInvalidResponseBody

type ListChatsInvalidResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListChatsInvalidResponseBody is the type of the "chat" service "listChats" endpoint HTTP response body for the "invalid" error.

type ListChatsInvariantViolationResponseBody

type ListChatsInvariantViolationResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListChatsInvariantViolationResponseBody is the type of the "chat" service "listChats" endpoint HTTP response body for the "invariant_violation" error.

type ListChatsNotFoundResponseBody

type ListChatsNotFoundResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListChatsNotFoundResponseBody is the type of the "chat" service "listChats" endpoint HTTP response body for the "not_found" error.

type ListChatsResponseBody

type ListChatsResponseBody struct {
	// The list of chats
	Chats []*ChatOverviewResponseBody `form:"chats,omitempty" json:"chats,omitempty" xml:"chats,omitempty"`
}

ListChatsResponseBody is the type of the "chat" service "listChats" endpoint HTTP response body.

type ListChatsUnauthorizedResponseBody

type ListChatsUnauthorizedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListChatsUnauthorizedResponseBody is the type of the "chat" service "listChats" endpoint HTTP response body for the "unauthorized" error.

type ListChatsUnexpectedResponseBody

type ListChatsUnexpectedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListChatsUnexpectedResponseBody is the type of the "chat" service "listChats" endpoint HTTP response body for the "unexpected" error.

type ListChatsUnsupportedMediaResponseBody

type ListChatsUnsupportedMediaResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListChatsUnsupportedMediaResponseBody is the type of the "chat" service "listChats" endpoint HTTP response body for the "unsupported_media" error.

type LoadChatBadRequestResponseBody

type LoadChatBadRequestResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

LoadChatBadRequestResponseBody is the type of the "chat" service "loadChat" endpoint HTTP response body for the "bad_request" error.

type LoadChatConflictResponseBody

type LoadChatConflictResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

LoadChatConflictResponseBody is the type of the "chat" service "loadChat" endpoint HTTP response body for the "conflict" error.

type LoadChatForbiddenResponseBody

type LoadChatForbiddenResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

LoadChatForbiddenResponseBody is the type of the "chat" service "loadChat" endpoint HTTP response body for the "forbidden" error.

type LoadChatGatewayErrorResponseBody

type LoadChatGatewayErrorResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

LoadChatGatewayErrorResponseBody is the type of the "chat" service "loadChat" endpoint HTTP response body for the "gateway_error" error.

type LoadChatInvalidResponseBody

type LoadChatInvalidResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

LoadChatInvalidResponseBody is the type of the "chat" service "loadChat" endpoint HTTP response body for the "invalid" error.

type LoadChatInvariantViolationResponseBody

type LoadChatInvariantViolationResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

LoadChatInvariantViolationResponseBody is the type of the "chat" service "loadChat" endpoint HTTP response body for the "invariant_violation" error.

type LoadChatNotFoundResponseBody

type LoadChatNotFoundResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

LoadChatNotFoundResponseBody is the type of the "chat" service "loadChat" endpoint HTTP response body for the "not_found" error.

type LoadChatResponseBody

type LoadChatResponseBody struct {
	// The list of messages in the chat
	Messages []*ChatMessageResponseBody `form:"messages,omitempty" json:"messages,omitempty" xml:"messages,omitempty"`
	// The ID of the chat
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// The title of the chat
	Title *string `form:"title,omitempty" json:"title,omitempty" xml:"title,omitempty"`
	// The ID of the user who created the chat
	UserID *string `form:"user_id,omitempty" json:"user_id,omitempty" xml:"user_id,omitempty"`
	// The number of messages in the chat
	NumMessages *int `form:"num_messages,omitempty" json:"num_messages,omitempty" xml:"num_messages,omitempty"`
	// When the chat was created.
	CreatedAt *string `form:"created_at,omitempty" json:"created_at,omitempty" xml:"created_at,omitempty"`
	// When the chat was last updated.
	UpdatedAt *string `form:"updated_at,omitempty" json:"updated_at,omitempty" xml:"updated_at,omitempty"`
}

LoadChatResponseBody is the type of the "chat" service "loadChat" endpoint HTTP response body.

type LoadChatUnauthorizedResponseBody

type LoadChatUnauthorizedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

LoadChatUnauthorizedResponseBody is the type of the "chat" service "loadChat" endpoint HTTP response body for the "unauthorized" error.

type LoadChatUnexpectedResponseBody

type LoadChatUnexpectedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

LoadChatUnexpectedResponseBody is the type of the "chat" service "loadChat" endpoint HTTP response body for the "unexpected" error.

type LoadChatUnsupportedMediaResponseBody

type LoadChatUnsupportedMediaResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

LoadChatUnsupportedMediaResponseBody is the type of the "chat" service "loadChat" endpoint HTTP response body for the "unsupported_media" error.

Jump to