client

package
v0.0.0-...-4ae6852 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2025 License: AGPL-3.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildCreateProjectPayload

func BuildCreateProjectPayload(projectsCreateProjectBody string, projectsCreateProjectApikeyToken string, projectsCreateProjectSessionToken string) (*projects.CreateProjectPayload, error)

BuildCreateProjectPayload builds the payload for the projects createProject endpoint from CLI flags.

func BuildListProjectsPayload

func BuildListProjectsPayload(projectsListProjectsOrganizationID string, projectsListProjectsApikeyToken string, projectsListProjectsSessionToken string) (*projects.ListProjectsPayload, error)

BuildListProjectsPayload builds the payload for the projects listProjects endpoint from CLI flags.

func BuildSetLogoPayload

func BuildSetLogoPayload(projectsSetLogoBody string, projectsSetLogoApikeyToken string, projectsSetLogoSessionToken string, projectsSetLogoProjectSlugInput string) (*projects.SetLogoPayload, error)

BuildSetLogoPayload builds the payload for the projects setLogo endpoint from CLI flags.

func CreateProjectProjectsPath

func CreateProjectProjectsPath() string

CreateProjectProjectsPath returns the URL path to the projects service createProject HTTP endpoint.

func DecodeCreateProjectResponse

func DecodeCreateProjectResponse(decoder func(*http.Response) goahttp.Decoder, restoreBody bool) func(*http.Response) (any, error)

DecodeCreateProjectResponse returns a decoder for responses returned by the projects createProject endpoint. restoreBody controls whether the response body should be restored after having been read. DecodeCreateProjectResponse may return the following errors:

  • "unauthorized" (type *goa.ServiceError): http.StatusUnauthorized
  • "forbidden" (type *goa.ServiceError): http.StatusForbidden
  • "bad_request" (type *goa.ServiceError): http.StatusBadRequest
  • "not_found" (type *goa.ServiceError): http.StatusNotFound
  • "conflict" (type *goa.ServiceError): http.StatusConflict
  • "unsupported_media" (type *goa.ServiceError): http.StatusUnsupportedMediaType
  • "invalid" (type *goa.ServiceError): http.StatusUnprocessableEntity
  • "invariant_violation" (type *goa.ServiceError): http.StatusInternalServerError
  • "unexpected" (type *goa.ServiceError): http.StatusInternalServerError
  • "gateway_error" (type *goa.ServiceError): http.StatusBadGateway
  • error: internal error

func DecodeListProjectsResponse

func DecodeListProjectsResponse(decoder func(*http.Response) goahttp.Decoder, restoreBody bool) func(*http.Response) (any, error)

DecodeListProjectsResponse returns a decoder for responses returned by the projects listProjects endpoint. restoreBody controls whether the response body should be restored after having been read. DecodeListProjectsResponse may return the following errors:

  • "unauthorized" (type *goa.ServiceError): http.StatusUnauthorized
  • "forbidden" (type *goa.ServiceError): http.StatusForbidden
  • "bad_request" (type *goa.ServiceError): http.StatusBadRequest
  • "not_found" (type *goa.ServiceError): http.StatusNotFound
  • "conflict" (type *goa.ServiceError): http.StatusConflict
  • "unsupported_media" (type *goa.ServiceError): http.StatusUnsupportedMediaType
  • "invalid" (type *goa.ServiceError): http.StatusUnprocessableEntity
  • "invariant_violation" (type *goa.ServiceError): http.StatusInternalServerError
  • "unexpected" (type *goa.ServiceError): http.StatusInternalServerError
  • "gateway_error" (type *goa.ServiceError): http.StatusBadGateway
  • error: internal error

func DecodeSetLogoResponse

func DecodeSetLogoResponse(decoder func(*http.Response) goahttp.Decoder, restoreBody bool) func(*http.Response) (any, error)

DecodeSetLogoResponse returns a decoder for responses returned by the projects setLogo endpoint. restoreBody controls whether the response body should be restored after having been read. DecodeSetLogoResponse may return the following errors:

  • "unauthorized" (type *goa.ServiceError): http.StatusUnauthorized
  • "forbidden" (type *goa.ServiceError): http.StatusForbidden
  • "bad_request" (type *goa.ServiceError): http.StatusBadRequest
  • "not_found" (type *goa.ServiceError): http.StatusNotFound
  • "conflict" (type *goa.ServiceError): http.StatusConflict
  • "unsupported_media" (type *goa.ServiceError): http.StatusUnsupportedMediaType
  • "invalid" (type *goa.ServiceError): http.StatusUnprocessableEntity
  • "invariant_violation" (type *goa.ServiceError): http.StatusInternalServerError
  • "unexpected" (type *goa.ServiceError): http.StatusInternalServerError
  • "gateway_error" (type *goa.ServiceError): http.StatusBadGateway
  • error: internal error

func EncodeCreateProjectRequest

func EncodeCreateProjectRequest(encoder func(*http.Request) goahttp.Encoder) func(*http.Request, any) error

EncodeCreateProjectRequest returns an encoder for requests sent to the projects createProject server.

func EncodeListProjectsRequest

func EncodeListProjectsRequest(encoder func(*http.Request) goahttp.Encoder) func(*http.Request, any) error

EncodeListProjectsRequest returns an encoder for requests sent to the projects listProjects server.

func EncodeSetLogoRequest

func EncodeSetLogoRequest(encoder func(*http.Request) goahttp.Encoder) func(*http.Request, any) error

EncodeSetLogoRequest returns an encoder for requests sent to the projects setLogo server.

func ListProjectsProjectsPath

func ListProjectsProjectsPath() string

ListProjectsProjectsPath returns the URL path to the projects service listProjects HTTP endpoint.

func NewCreateProjectBadRequest

func NewCreateProjectBadRequest(body *CreateProjectBadRequestResponseBody) *goa.ServiceError

NewCreateProjectBadRequest builds a projects service createProject endpoint bad_request error.

func NewCreateProjectConflict

func NewCreateProjectConflict(body *CreateProjectConflictResponseBody) *goa.ServiceError

NewCreateProjectConflict builds a projects service createProject endpoint conflict error.

func NewCreateProjectForbidden

func NewCreateProjectForbidden(body *CreateProjectForbiddenResponseBody) *goa.ServiceError

NewCreateProjectForbidden builds a projects service createProject endpoint forbidden error.

func NewCreateProjectGatewayError

func NewCreateProjectGatewayError(body *CreateProjectGatewayErrorResponseBody) *goa.ServiceError

NewCreateProjectGatewayError builds a projects service createProject endpoint gateway_error error.

func NewCreateProjectInvalid

func NewCreateProjectInvalid(body *CreateProjectInvalidResponseBody) *goa.ServiceError

NewCreateProjectInvalid builds a projects service createProject endpoint invalid error.

func NewCreateProjectInvariantViolation

func NewCreateProjectInvariantViolation(body *CreateProjectInvariantViolationResponseBody) *goa.ServiceError

NewCreateProjectInvariantViolation builds a projects service createProject endpoint invariant_violation error.

func NewCreateProjectNotFound

func NewCreateProjectNotFound(body *CreateProjectNotFoundResponseBody) *goa.ServiceError

NewCreateProjectNotFound builds a projects service createProject endpoint not_found error.

func NewCreateProjectResultOK

func NewCreateProjectResultOK(body *CreateProjectResponseBody) *projects.CreateProjectResult

NewCreateProjectResultOK builds a "projects" service "createProject" endpoint result from a HTTP "OK" response.

func NewCreateProjectUnauthorized

func NewCreateProjectUnauthorized(body *CreateProjectUnauthorizedResponseBody) *goa.ServiceError

NewCreateProjectUnauthorized builds a projects service createProject endpoint unauthorized error.

func NewCreateProjectUnexpected

func NewCreateProjectUnexpected(body *CreateProjectUnexpectedResponseBody) *goa.ServiceError

NewCreateProjectUnexpected builds a projects service createProject endpoint unexpected error.

func NewCreateProjectUnsupportedMedia

func NewCreateProjectUnsupportedMedia(body *CreateProjectUnsupportedMediaResponseBody) *goa.ServiceError

NewCreateProjectUnsupportedMedia builds a projects service createProject endpoint unsupported_media error.

func NewListProjectsBadRequest

func NewListProjectsBadRequest(body *ListProjectsBadRequestResponseBody) *goa.ServiceError

NewListProjectsBadRequest builds a projects service listProjects endpoint bad_request error.

func NewListProjectsConflict

func NewListProjectsConflict(body *ListProjectsConflictResponseBody) *goa.ServiceError

NewListProjectsConflict builds a projects service listProjects endpoint conflict error.

func NewListProjectsForbidden

func NewListProjectsForbidden(body *ListProjectsForbiddenResponseBody) *goa.ServiceError

NewListProjectsForbidden builds a projects service listProjects endpoint forbidden error.

func NewListProjectsGatewayError

func NewListProjectsGatewayError(body *ListProjectsGatewayErrorResponseBody) *goa.ServiceError

NewListProjectsGatewayError builds a projects service listProjects endpoint gateway_error error.

func NewListProjectsInvalid

func NewListProjectsInvalid(body *ListProjectsInvalidResponseBody) *goa.ServiceError

NewListProjectsInvalid builds a projects service listProjects endpoint invalid error.

func NewListProjectsInvariantViolation

func NewListProjectsInvariantViolation(body *ListProjectsInvariantViolationResponseBody) *goa.ServiceError

NewListProjectsInvariantViolation builds a projects service listProjects endpoint invariant_violation error.

func NewListProjectsNotFound

func NewListProjectsNotFound(body *ListProjectsNotFoundResponseBody) *goa.ServiceError

NewListProjectsNotFound builds a projects service listProjects endpoint not_found error.

func NewListProjectsResultOK

func NewListProjectsResultOK(body *ListProjectsResponseBody) *projects.ListProjectsResult

NewListProjectsResultOK builds a "projects" service "listProjects" endpoint result from a HTTP "OK" response.

func NewListProjectsUnauthorized

func NewListProjectsUnauthorized(body *ListProjectsUnauthorizedResponseBody) *goa.ServiceError

NewListProjectsUnauthorized builds a projects service listProjects endpoint unauthorized error.

func NewListProjectsUnexpected

func NewListProjectsUnexpected(body *ListProjectsUnexpectedResponseBody) *goa.ServiceError

NewListProjectsUnexpected builds a projects service listProjects endpoint unexpected error.

func NewListProjectsUnsupportedMedia

func NewListProjectsUnsupportedMedia(body *ListProjectsUnsupportedMediaResponseBody) *goa.ServiceError

NewListProjectsUnsupportedMedia builds a projects service listProjects endpoint unsupported_media error.

func NewSetLogoBadRequest

func NewSetLogoBadRequest(body *SetLogoBadRequestResponseBody) *goa.ServiceError

NewSetLogoBadRequest builds a projects service setLogo endpoint bad_request error.

func NewSetLogoConflict

func NewSetLogoConflict(body *SetLogoConflictResponseBody) *goa.ServiceError

NewSetLogoConflict builds a projects service setLogo endpoint conflict error.

func NewSetLogoForbidden

func NewSetLogoForbidden(body *SetLogoForbiddenResponseBody) *goa.ServiceError

NewSetLogoForbidden builds a projects service setLogo endpoint forbidden error.

func NewSetLogoGatewayError

func NewSetLogoGatewayError(body *SetLogoGatewayErrorResponseBody) *goa.ServiceError

NewSetLogoGatewayError builds a projects service setLogo endpoint gateway_error error.

func NewSetLogoInvalid

func NewSetLogoInvalid(body *SetLogoInvalidResponseBody) *goa.ServiceError

NewSetLogoInvalid builds a projects service setLogo endpoint invalid error.

func NewSetLogoInvariantViolation

func NewSetLogoInvariantViolation(body *SetLogoInvariantViolationResponseBody) *goa.ServiceError

NewSetLogoInvariantViolation builds a projects service setLogo endpoint invariant_violation error.

func NewSetLogoNotFound

func NewSetLogoNotFound(body *SetLogoNotFoundResponseBody) *goa.ServiceError

NewSetLogoNotFound builds a projects service setLogo endpoint not_found error.

func NewSetLogoSetProjectLogoResultOK

func NewSetLogoSetProjectLogoResultOK(body *SetLogoResponseBody) *projects.SetProjectLogoResult

NewSetLogoSetProjectLogoResultOK builds a "projects" service "setLogo" endpoint result from a HTTP "OK" response.

func NewSetLogoUnauthorized

func NewSetLogoUnauthorized(body *SetLogoUnauthorizedResponseBody) *goa.ServiceError

NewSetLogoUnauthorized builds a projects service setLogo endpoint unauthorized error.

func NewSetLogoUnexpected

func NewSetLogoUnexpected(body *SetLogoUnexpectedResponseBody) *goa.ServiceError

NewSetLogoUnexpected builds a projects service setLogo endpoint unexpected error.

func NewSetLogoUnsupportedMedia

func NewSetLogoUnsupportedMedia(body *SetLogoUnsupportedMediaResponseBody) *goa.ServiceError

NewSetLogoUnsupportedMedia builds a projects service setLogo endpoint unsupported_media error.

func SetLogoProjectsPath

func SetLogoProjectsPath() string

SetLogoProjectsPath returns the URL path to the projects service setLogo HTTP endpoint.

func ValidateCreateProjectBadRequestResponseBody

func ValidateCreateProjectBadRequestResponseBody(body *CreateProjectBadRequestResponseBody) (err error)

ValidateCreateProjectBadRequestResponseBody runs the validations defined on createProject_bad_request_response_body

func ValidateCreateProjectConflictResponseBody

func ValidateCreateProjectConflictResponseBody(body *CreateProjectConflictResponseBody) (err error)

ValidateCreateProjectConflictResponseBody runs the validations defined on createProject_conflict_response_body

func ValidateCreateProjectForbiddenResponseBody

func ValidateCreateProjectForbiddenResponseBody(body *CreateProjectForbiddenResponseBody) (err error)

ValidateCreateProjectForbiddenResponseBody runs the validations defined on createProject_forbidden_response_body

func ValidateCreateProjectGatewayErrorResponseBody

func ValidateCreateProjectGatewayErrorResponseBody(body *CreateProjectGatewayErrorResponseBody) (err error)

ValidateCreateProjectGatewayErrorResponseBody runs the validations defined on createProject_gateway_error_response_body

func ValidateCreateProjectInvalidResponseBody

func ValidateCreateProjectInvalidResponseBody(body *CreateProjectInvalidResponseBody) (err error)

ValidateCreateProjectInvalidResponseBody runs the validations defined on createProject_invalid_response_body

func ValidateCreateProjectInvariantViolationResponseBody

func ValidateCreateProjectInvariantViolationResponseBody(body *CreateProjectInvariantViolationResponseBody) (err error)

ValidateCreateProjectInvariantViolationResponseBody runs the validations defined on createProject_invariant_violation_response_body

func ValidateCreateProjectNotFoundResponseBody

func ValidateCreateProjectNotFoundResponseBody(body *CreateProjectNotFoundResponseBody) (err error)

ValidateCreateProjectNotFoundResponseBody runs the validations defined on createProject_not_found_response_body

func ValidateCreateProjectResponseBody

func ValidateCreateProjectResponseBody(body *CreateProjectResponseBody) (err error)

ValidateCreateProjectResponseBody runs the validations defined on CreateProjectResponseBody

func ValidateCreateProjectUnauthorizedResponseBody

func ValidateCreateProjectUnauthorizedResponseBody(body *CreateProjectUnauthorizedResponseBody) (err error)

ValidateCreateProjectUnauthorizedResponseBody runs the validations defined on createProject_unauthorized_response_body

func ValidateCreateProjectUnexpectedResponseBody

func ValidateCreateProjectUnexpectedResponseBody(body *CreateProjectUnexpectedResponseBody) (err error)

ValidateCreateProjectUnexpectedResponseBody runs the validations defined on createProject_unexpected_response_body

func ValidateCreateProjectUnsupportedMediaResponseBody

func ValidateCreateProjectUnsupportedMediaResponseBody(body *CreateProjectUnsupportedMediaResponseBody) (err error)

ValidateCreateProjectUnsupportedMediaResponseBody runs the validations defined on createProject_unsupported_media_response_body

func ValidateListProjectsBadRequestResponseBody

func ValidateListProjectsBadRequestResponseBody(body *ListProjectsBadRequestResponseBody) (err error)

ValidateListProjectsBadRequestResponseBody runs the validations defined on listProjects_bad_request_response_body

func ValidateListProjectsConflictResponseBody

func ValidateListProjectsConflictResponseBody(body *ListProjectsConflictResponseBody) (err error)

ValidateListProjectsConflictResponseBody runs the validations defined on listProjects_conflict_response_body

func ValidateListProjectsForbiddenResponseBody

func ValidateListProjectsForbiddenResponseBody(body *ListProjectsForbiddenResponseBody) (err error)

ValidateListProjectsForbiddenResponseBody runs the validations defined on listProjects_forbidden_response_body

func ValidateListProjectsGatewayErrorResponseBody

func ValidateListProjectsGatewayErrorResponseBody(body *ListProjectsGatewayErrorResponseBody) (err error)

ValidateListProjectsGatewayErrorResponseBody runs the validations defined on listProjects_gateway_error_response_body

func ValidateListProjectsInvalidResponseBody

func ValidateListProjectsInvalidResponseBody(body *ListProjectsInvalidResponseBody) (err error)

ValidateListProjectsInvalidResponseBody runs the validations defined on listProjects_invalid_response_body

func ValidateListProjectsInvariantViolationResponseBody

func ValidateListProjectsInvariantViolationResponseBody(body *ListProjectsInvariantViolationResponseBody) (err error)

ValidateListProjectsInvariantViolationResponseBody runs the validations defined on listProjects_invariant_violation_response_body

func ValidateListProjectsNotFoundResponseBody

func ValidateListProjectsNotFoundResponseBody(body *ListProjectsNotFoundResponseBody) (err error)

ValidateListProjectsNotFoundResponseBody runs the validations defined on listProjects_not_found_response_body

func ValidateListProjectsResponseBody

func ValidateListProjectsResponseBody(body *ListProjectsResponseBody) (err error)

ValidateListProjectsResponseBody runs the validations defined on ListProjectsResponseBody

func ValidateListProjectsUnauthorizedResponseBody

func ValidateListProjectsUnauthorizedResponseBody(body *ListProjectsUnauthorizedResponseBody) (err error)

ValidateListProjectsUnauthorizedResponseBody runs the validations defined on listProjects_unauthorized_response_body

func ValidateListProjectsUnexpectedResponseBody

func ValidateListProjectsUnexpectedResponseBody(body *ListProjectsUnexpectedResponseBody) (err error)

ValidateListProjectsUnexpectedResponseBody runs the validations defined on listProjects_unexpected_response_body

func ValidateListProjectsUnsupportedMediaResponseBody

func ValidateListProjectsUnsupportedMediaResponseBody(body *ListProjectsUnsupportedMediaResponseBody) (err error)

ValidateListProjectsUnsupportedMediaResponseBody runs the validations defined on listProjects_unsupported_media_response_body

func ValidateProjectEntryResponseBody

func ValidateProjectEntryResponseBody(body *ProjectEntryResponseBody) (err error)

ValidateProjectEntryResponseBody runs the validations defined on ProjectEntryResponseBody

func ValidateProjectResponseBody

func ValidateProjectResponseBody(body *ProjectResponseBody) (err error)

ValidateProjectResponseBody runs the validations defined on ProjectResponseBody

func ValidateSetLogoBadRequestResponseBody

func ValidateSetLogoBadRequestResponseBody(body *SetLogoBadRequestResponseBody) (err error)

ValidateSetLogoBadRequestResponseBody runs the validations defined on setLogo_bad_request_response_body

func ValidateSetLogoConflictResponseBody

func ValidateSetLogoConflictResponseBody(body *SetLogoConflictResponseBody) (err error)

ValidateSetLogoConflictResponseBody runs the validations defined on setLogo_conflict_response_body

func ValidateSetLogoForbiddenResponseBody

func ValidateSetLogoForbiddenResponseBody(body *SetLogoForbiddenResponseBody) (err error)

ValidateSetLogoForbiddenResponseBody runs the validations defined on setLogo_forbidden_response_body

func ValidateSetLogoGatewayErrorResponseBody

func ValidateSetLogoGatewayErrorResponseBody(body *SetLogoGatewayErrorResponseBody) (err error)

ValidateSetLogoGatewayErrorResponseBody runs the validations defined on setLogo_gateway_error_response_body

func ValidateSetLogoInvalidResponseBody

func ValidateSetLogoInvalidResponseBody(body *SetLogoInvalidResponseBody) (err error)

ValidateSetLogoInvalidResponseBody runs the validations defined on setLogo_invalid_response_body

func ValidateSetLogoInvariantViolationResponseBody

func ValidateSetLogoInvariantViolationResponseBody(body *SetLogoInvariantViolationResponseBody) (err error)

ValidateSetLogoInvariantViolationResponseBody runs the validations defined on setLogo_invariant_violation_response_body

func ValidateSetLogoNotFoundResponseBody

func ValidateSetLogoNotFoundResponseBody(body *SetLogoNotFoundResponseBody) (err error)

ValidateSetLogoNotFoundResponseBody runs the validations defined on setLogo_not_found_response_body

func ValidateSetLogoResponseBody

func ValidateSetLogoResponseBody(body *SetLogoResponseBody) (err error)

ValidateSetLogoResponseBody runs the validations defined on SetLogoResponseBody

func ValidateSetLogoUnauthorizedResponseBody

func ValidateSetLogoUnauthorizedResponseBody(body *SetLogoUnauthorizedResponseBody) (err error)

ValidateSetLogoUnauthorizedResponseBody runs the validations defined on setLogo_unauthorized_response_body

func ValidateSetLogoUnexpectedResponseBody

func ValidateSetLogoUnexpectedResponseBody(body *SetLogoUnexpectedResponseBody) (err error)

ValidateSetLogoUnexpectedResponseBody runs the validations defined on setLogo_unexpected_response_body

func ValidateSetLogoUnsupportedMediaResponseBody

func ValidateSetLogoUnsupportedMediaResponseBody(body *SetLogoUnsupportedMediaResponseBody) (err error)

ValidateSetLogoUnsupportedMediaResponseBody runs the validations defined on setLogo_unsupported_media_response_body

Types

type Client

type Client struct {
	// CreateProject Doer is the HTTP client used to make requests to the
	// createProject endpoint.
	CreateProjectDoer goahttp.Doer

	// ListProjects Doer is the HTTP client used to make requests to the
	// listProjects endpoint.
	ListProjectsDoer goahttp.Doer

	// SetLogo Doer is the HTTP client used to make requests to the setLogo
	// endpoint.
	SetLogoDoer goahttp.Doer

	// RestoreResponseBody controls whether the response bodies are reset after
	// decoding so they can be read again.
	RestoreResponseBody bool
	// contains filtered or unexported fields
}

Client lists the projects service endpoint HTTP clients.

func NewClient

func NewClient(
	scheme string,
	host string,
	doer goahttp.Doer,
	enc func(*http.Request) goahttp.Encoder,
	dec func(*http.Response) goahttp.Decoder,
	restoreBody bool,
) *Client

NewClient instantiates HTTP clients for all the projects service servers.

func (*Client) BuildCreateProjectRequest

func (c *Client) BuildCreateProjectRequest(ctx context.Context, v any) (*http.Request, error)

BuildCreateProjectRequest instantiates a HTTP request object with method and path set to call the "projects" service "createProject" endpoint

func (*Client) BuildListProjectsRequest

func (c *Client) BuildListProjectsRequest(ctx context.Context, v any) (*http.Request, error)

BuildListProjectsRequest instantiates a HTTP request object with method and path set to call the "projects" service "listProjects" endpoint

func (*Client) BuildSetLogoRequest

func (c *Client) BuildSetLogoRequest(ctx context.Context, v any) (*http.Request, error)

BuildSetLogoRequest instantiates a HTTP request object with method and path set to call the "projects" service "setLogo" endpoint

func (*Client) CreateProject

func (c *Client) CreateProject() goa.Endpoint

CreateProject returns an endpoint that makes HTTP requests to the projects service createProject server.

func (*Client) ListProjects

func (c *Client) ListProjects() goa.Endpoint

ListProjects returns an endpoint that makes HTTP requests to the projects service listProjects server.

func (c *Client) SetLogo() goa.Endpoint

SetLogo returns an endpoint that makes HTTP requests to the projects service setLogo server.

type CreateProjectBadRequestResponseBody

type CreateProjectBadRequestResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreateProjectBadRequestResponseBody is the type of the "projects" service "createProject" endpoint HTTP response body for the "bad_request" error.

type CreateProjectConflictResponseBody

type CreateProjectConflictResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreateProjectConflictResponseBody is the type of the "projects" service "createProject" endpoint HTTP response body for the "conflict" error.

type CreateProjectForbiddenResponseBody

type CreateProjectForbiddenResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreateProjectForbiddenResponseBody is the type of the "projects" service "createProject" endpoint HTTP response body for the "forbidden" error.

type CreateProjectGatewayErrorResponseBody

type CreateProjectGatewayErrorResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreateProjectGatewayErrorResponseBody is the type of the "projects" service "createProject" endpoint HTTP response body for the "gateway_error" error.

type CreateProjectInvalidResponseBody

type CreateProjectInvalidResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreateProjectInvalidResponseBody is the type of the "projects" service "createProject" endpoint HTTP response body for the "invalid" error.

type CreateProjectInvariantViolationResponseBody

type CreateProjectInvariantViolationResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreateProjectInvariantViolationResponseBody is the type of the "projects" service "createProject" endpoint HTTP response body for the "invariant_violation" error.

type CreateProjectNotFoundResponseBody

type CreateProjectNotFoundResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreateProjectNotFoundResponseBody is the type of the "projects" service "createProject" endpoint HTTP response body for the "not_found" error.

type CreateProjectRequestBody

type CreateProjectRequestBody struct {
	// The ID of the organization to create the project in
	OrganizationID string `form:"organization_id" json:"organization_id" xml:"organization_id"`
	// The name of the project
	Name string `form:"name" json:"name" xml:"name"`
}

CreateProjectRequestBody is the type of the "projects" service "createProject" endpoint HTTP request body.

func NewCreateProjectRequestBody

func NewCreateProjectRequestBody(p *projects.CreateProjectPayload) *CreateProjectRequestBody

NewCreateProjectRequestBody builds the HTTP request body from the payload of the "createProject" endpoint of the "projects" service.

type CreateProjectResponseBody

type CreateProjectResponseBody struct {
	// The created project
	Project *ProjectResponseBody `form:"project,omitempty" json:"project,omitempty" xml:"project,omitempty"`
}

CreateProjectResponseBody is the type of the "projects" service "createProject" endpoint HTTP response body.

type CreateProjectUnauthorizedResponseBody

type CreateProjectUnauthorizedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreateProjectUnauthorizedResponseBody is the type of the "projects" service "createProject" endpoint HTTP response body for the "unauthorized" error.

type CreateProjectUnexpectedResponseBody

type CreateProjectUnexpectedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreateProjectUnexpectedResponseBody is the type of the "projects" service "createProject" endpoint HTTP response body for the "unexpected" error.

type CreateProjectUnsupportedMediaResponseBody

type CreateProjectUnsupportedMediaResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

CreateProjectUnsupportedMediaResponseBody is the type of the "projects" service "createProject" endpoint HTTP response body for the "unsupported_media" error.

type ListProjectsBadRequestResponseBody

type ListProjectsBadRequestResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListProjectsBadRequestResponseBody is the type of the "projects" service "listProjects" endpoint HTTP response body for the "bad_request" error.

type ListProjectsConflictResponseBody

type ListProjectsConflictResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListProjectsConflictResponseBody is the type of the "projects" service "listProjects" endpoint HTTP response body for the "conflict" error.

type ListProjectsForbiddenResponseBody

type ListProjectsForbiddenResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListProjectsForbiddenResponseBody is the type of the "projects" service "listProjects" endpoint HTTP response body for the "forbidden" error.

type ListProjectsGatewayErrorResponseBody

type ListProjectsGatewayErrorResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListProjectsGatewayErrorResponseBody is the type of the "projects" service "listProjects" endpoint HTTP response body for the "gateway_error" error.

type ListProjectsInvalidResponseBody

type ListProjectsInvalidResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListProjectsInvalidResponseBody is the type of the "projects" service "listProjects" endpoint HTTP response body for the "invalid" error.

type ListProjectsInvariantViolationResponseBody

type ListProjectsInvariantViolationResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListProjectsInvariantViolationResponseBody is the type of the "projects" service "listProjects" endpoint HTTP response body for the "invariant_violation" error.

type ListProjectsNotFoundResponseBody

type ListProjectsNotFoundResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListProjectsNotFoundResponseBody is the type of the "projects" service "listProjects" endpoint HTTP response body for the "not_found" error.

type ListProjectsResponseBody

type ListProjectsResponseBody struct {
	// The list of projects
	Projects []*ProjectEntryResponseBody `form:"projects,omitempty" json:"projects,omitempty" xml:"projects,omitempty"`
}

ListProjectsResponseBody is the type of the "projects" service "listProjects" endpoint HTTP response body.

type ListProjectsUnauthorizedResponseBody

type ListProjectsUnauthorizedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListProjectsUnauthorizedResponseBody is the type of the "projects" service "listProjects" endpoint HTTP response body for the "unauthorized" error.

type ListProjectsUnexpectedResponseBody

type ListProjectsUnexpectedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListProjectsUnexpectedResponseBody is the type of the "projects" service "listProjects" endpoint HTTP response body for the "unexpected" error.

type ListProjectsUnsupportedMediaResponseBody

type ListProjectsUnsupportedMediaResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListProjectsUnsupportedMediaResponseBody is the type of the "projects" service "listProjects" endpoint HTTP response body for the "unsupported_media" error.

type ProjectEntryResponseBody

type ProjectEntryResponseBody struct {
	// The ID of the project
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// The name of the project
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// The slug of the project
	Slug *string `form:"slug,omitempty" json:"slug,omitempty" xml:"slug,omitempty"`
}

ProjectEntryResponseBody is used to define fields on response body types.

type ProjectResponseBody

type ProjectResponseBody struct {
	// The ID of the project
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// The name of the project
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// The slug of the project
	Slug *string `form:"slug,omitempty" json:"slug,omitempty" xml:"slug,omitempty"`
	// The ID of the organization that owns the project
	OrganizationID *string `form:"organization_id,omitempty" json:"organization_id,omitempty" xml:"organization_id,omitempty"`
	// The ID of the logo asset for the project
	LogoAssetID *string `form:"logo_asset_id,omitempty" json:"logo_asset_id,omitempty" xml:"logo_asset_id,omitempty"`
	// The creation date of the project.
	CreatedAt *string `form:"created_at,omitempty" json:"created_at,omitempty" xml:"created_at,omitempty"`
	// The last update date of the project.
	UpdatedAt *string `form:"updated_at,omitempty" json:"updated_at,omitempty" xml:"updated_at,omitempty"`
}

ProjectResponseBody is used to define fields on response body types.

type SetLogoBadRequestResponseBody

type SetLogoBadRequestResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

SetLogoBadRequestResponseBody is the type of the "projects" service "setLogo" endpoint HTTP response body for the "bad_request" error.

type SetLogoConflictResponseBody

type SetLogoConflictResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

SetLogoConflictResponseBody is the type of the "projects" service "setLogo" endpoint HTTP response body for the "conflict" error.

type SetLogoForbiddenResponseBody

type SetLogoForbiddenResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

SetLogoForbiddenResponseBody is the type of the "projects" service "setLogo" endpoint HTTP response body for the "forbidden" error.

type SetLogoGatewayErrorResponseBody

type SetLogoGatewayErrorResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

SetLogoGatewayErrorResponseBody is the type of the "projects" service "setLogo" endpoint HTTP response body for the "gateway_error" error.

type SetLogoInvalidResponseBody

type SetLogoInvalidResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

SetLogoInvalidResponseBody is the type of the "projects" service "setLogo" endpoint HTTP response body for the "invalid" error.

type SetLogoInvariantViolationResponseBody

type SetLogoInvariantViolationResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

SetLogoInvariantViolationResponseBody is the type of the "projects" service "setLogo" endpoint HTTP response body for the "invariant_violation" error.

type SetLogoNotFoundResponseBody

type SetLogoNotFoundResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

SetLogoNotFoundResponseBody is the type of the "projects" service "setLogo" endpoint HTTP response body for the "not_found" error.

type SetLogoRequestBody

type SetLogoRequestBody struct {
	// The ID of the asset
	AssetID string `form:"asset_id" json:"asset_id" xml:"asset_id"`
}

SetLogoRequestBody is the type of the "projects" service "setLogo" endpoint HTTP request body.

func NewSetLogoRequestBody

func NewSetLogoRequestBody(p *projects.SetLogoPayload) *SetLogoRequestBody

NewSetLogoRequestBody builds the HTTP request body from the payload of the "setLogo" endpoint of the "projects" service.

type SetLogoResponseBody

type SetLogoResponseBody struct {
	// The updated project with the new logo
	Project *ProjectResponseBody `form:"project,omitempty" json:"project,omitempty" xml:"project,omitempty"`
}

SetLogoResponseBody is the type of the "projects" service "setLogo" endpoint HTTP response body.

type SetLogoUnauthorizedResponseBody

type SetLogoUnauthorizedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

SetLogoUnauthorizedResponseBody is the type of the "projects" service "setLogo" endpoint HTTP response body for the "unauthorized" error.

type SetLogoUnexpectedResponseBody

type SetLogoUnexpectedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

SetLogoUnexpectedResponseBody is the type of the "projects" service "setLogo" endpoint HTTP response body for the "unexpected" error.

type SetLogoUnsupportedMediaResponseBody

type SetLogoUnsupportedMediaResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

SetLogoUnsupportedMediaResponseBody is the type of the "projects" service "setLogo" endpoint HTTP response body for the "unsupported_media" error.

Jump to