client

package
v0.0.0-...-4ae6852 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2025 License: AGPL-3.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildListToolsPayload

func BuildListToolsPayload(toolsListToolsCursor string, toolsListToolsLimit string, toolsListToolsDeploymentID string, toolsListToolsSessionToken string, toolsListToolsProjectSlugInput string) (*tools.ListToolsPayload, error)

BuildListToolsPayload builds the payload for the tools listTools endpoint from CLI flags.

func DecodeListToolsResponse

func DecodeListToolsResponse(decoder func(*http.Response) goahttp.Decoder, restoreBody bool) func(*http.Response) (any, error)

DecodeListToolsResponse returns a decoder for responses returned by the tools listTools endpoint. restoreBody controls whether the response body should be restored after having been read. DecodeListToolsResponse may return the following errors:

  • "unauthorized" (type *goa.ServiceError): http.StatusUnauthorized
  • "forbidden" (type *goa.ServiceError): http.StatusForbidden
  • "bad_request" (type *goa.ServiceError): http.StatusBadRequest
  • "not_found" (type *goa.ServiceError): http.StatusNotFound
  • "conflict" (type *goa.ServiceError): http.StatusConflict
  • "unsupported_media" (type *goa.ServiceError): http.StatusUnsupportedMediaType
  • "invalid" (type *goa.ServiceError): http.StatusUnprocessableEntity
  • "invariant_violation" (type *goa.ServiceError): http.StatusInternalServerError
  • "unexpected" (type *goa.ServiceError): http.StatusInternalServerError
  • "gateway_error" (type *goa.ServiceError): http.StatusBadGateway
  • error: internal error

func EncodeListToolsRequest

func EncodeListToolsRequest(encoder func(*http.Request) goahttp.Encoder) func(*http.Request, any) error

EncodeListToolsRequest returns an encoder for requests sent to the tools listTools server.

func ListToolsToolsPath

func ListToolsToolsPath() string

ListToolsToolsPath returns the URL path to the tools service listTools HTTP endpoint.

func NewListToolsBadRequest

func NewListToolsBadRequest(body *ListToolsBadRequestResponseBody) *goa.ServiceError

NewListToolsBadRequest builds a tools service listTools endpoint bad_request error.

func NewListToolsConflict

func NewListToolsConflict(body *ListToolsConflictResponseBody) *goa.ServiceError

NewListToolsConflict builds a tools service listTools endpoint conflict error.

func NewListToolsForbidden

func NewListToolsForbidden(body *ListToolsForbiddenResponseBody) *goa.ServiceError

NewListToolsForbidden builds a tools service listTools endpoint forbidden error.

func NewListToolsGatewayError

func NewListToolsGatewayError(body *ListToolsGatewayErrorResponseBody) *goa.ServiceError

NewListToolsGatewayError builds a tools service listTools endpoint gateway_error error.

func NewListToolsInvalid

func NewListToolsInvalid(body *ListToolsInvalidResponseBody) *goa.ServiceError

NewListToolsInvalid builds a tools service listTools endpoint invalid error.

func NewListToolsInvariantViolation

func NewListToolsInvariantViolation(body *ListToolsInvariantViolationResponseBody) *goa.ServiceError

NewListToolsInvariantViolation builds a tools service listTools endpoint invariant_violation error.

func NewListToolsNotFound

func NewListToolsNotFound(body *ListToolsNotFoundResponseBody) *goa.ServiceError

NewListToolsNotFound builds a tools service listTools endpoint not_found error.

func NewListToolsResultOK

func NewListToolsResultOK(body *ListToolsResponseBody) *tools.ListToolsResult

NewListToolsResultOK builds a "tools" service "listTools" endpoint result from a HTTP "OK" response.

func NewListToolsUnauthorized

func NewListToolsUnauthorized(body *ListToolsUnauthorizedResponseBody) *goa.ServiceError

NewListToolsUnauthorized builds a tools service listTools endpoint unauthorized error.

func NewListToolsUnexpected

func NewListToolsUnexpected(body *ListToolsUnexpectedResponseBody) *goa.ServiceError

NewListToolsUnexpected builds a tools service listTools endpoint unexpected error.

func NewListToolsUnsupportedMedia

func NewListToolsUnsupportedMedia(body *ListToolsUnsupportedMediaResponseBody) *goa.ServiceError

NewListToolsUnsupportedMedia builds a tools service listTools endpoint unsupported_media error.

func ValidateCanonicalToolAttributesResponseBody

func ValidateCanonicalToolAttributesResponseBody(body *CanonicalToolAttributesResponseBody) (err error)

ValidateCanonicalToolAttributesResponseBody runs the validations defined on CanonicalToolAttributesResponseBody

func ValidateFunctionToolDefinitionResponseBody

func ValidateFunctionToolDefinitionResponseBody(body *FunctionToolDefinitionResponseBody) (err error)

ValidateFunctionToolDefinitionResponseBody runs the validations defined on FunctionToolDefinitionResponseBody

func ValidateHTTPToolDefinitionResponseBody

func ValidateHTTPToolDefinitionResponseBody(body *HTTPToolDefinitionResponseBody) (err error)

ValidateHTTPToolDefinitionResponseBody runs the validations defined on HTTPToolDefinitionResponseBody

func ValidateListToolsBadRequestResponseBody

func ValidateListToolsBadRequestResponseBody(body *ListToolsBadRequestResponseBody) (err error)

ValidateListToolsBadRequestResponseBody runs the validations defined on listTools_bad_request_response_body

func ValidateListToolsConflictResponseBody

func ValidateListToolsConflictResponseBody(body *ListToolsConflictResponseBody) (err error)

ValidateListToolsConflictResponseBody runs the validations defined on listTools_conflict_response_body

func ValidateListToolsForbiddenResponseBody

func ValidateListToolsForbiddenResponseBody(body *ListToolsForbiddenResponseBody) (err error)

ValidateListToolsForbiddenResponseBody runs the validations defined on listTools_forbidden_response_body

func ValidateListToolsGatewayErrorResponseBody

func ValidateListToolsGatewayErrorResponseBody(body *ListToolsGatewayErrorResponseBody) (err error)

ValidateListToolsGatewayErrorResponseBody runs the validations defined on listTools_gateway_error_response_body

func ValidateListToolsInvalidResponseBody

func ValidateListToolsInvalidResponseBody(body *ListToolsInvalidResponseBody) (err error)

ValidateListToolsInvalidResponseBody runs the validations defined on listTools_invalid_response_body

func ValidateListToolsInvariantViolationResponseBody

func ValidateListToolsInvariantViolationResponseBody(body *ListToolsInvariantViolationResponseBody) (err error)

ValidateListToolsInvariantViolationResponseBody runs the validations defined on listTools_invariant_violation_response_body

func ValidateListToolsNotFoundResponseBody

func ValidateListToolsNotFoundResponseBody(body *ListToolsNotFoundResponseBody) (err error)

ValidateListToolsNotFoundResponseBody runs the validations defined on listTools_not_found_response_body

func ValidateListToolsResponseBody

func ValidateListToolsResponseBody(body *ListToolsResponseBody) (err error)

ValidateListToolsResponseBody runs the validations defined on ListToolsResponseBody

func ValidateListToolsUnauthorizedResponseBody

func ValidateListToolsUnauthorizedResponseBody(body *ListToolsUnauthorizedResponseBody) (err error)

ValidateListToolsUnauthorizedResponseBody runs the validations defined on listTools_unauthorized_response_body

func ValidateListToolsUnexpectedResponseBody

func ValidateListToolsUnexpectedResponseBody(body *ListToolsUnexpectedResponseBody) (err error)

ValidateListToolsUnexpectedResponseBody runs the validations defined on listTools_unexpected_response_body

func ValidateListToolsUnsupportedMediaResponseBody

func ValidateListToolsUnsupportedMediaResponseBody(body *ListToolsUnsupportedMediaResponseBody) (err error)

ValidateListToolsUnsupportedMediaResponseBody runs the validations defined on listTools_unsupported_media_response_body

func ValidatePromptTemplateResponseBody

func ValidatePromptTemplateResponseBody(body *PromptTemplateResponseBody) (err error)

ValidatePromptTemplateResponseBody runs the validations defined on PromptTemplateResponseBody

func ValidateResponseFilterResponseBody

func ValidateResponseFilterResponseBody(body *ResponseFilterResponseBody) (err error)

ValidateResponseFilterResponseBody runs the validations defined on ResponseFilterResponseBody

func ValidateToolResponseBody

func ValidateToolResponseBody(body *ToolResponseBody) (err error)

ValidateToolResponseBody runs the validations defined on ToolResponseBody

func ValidateToolVariationResponseBody

func ValidateToolVariationResponseBody(body *ToolVariationResponseBody) (err error)

ValidateToolVariationResponseBody runs the validations defined on ToolVariationResponseBody

Types

type CanonicalToolAttributesResponseBody

type CanonicalToolAttributesResponseBody struct {
	// The ID of the variation that was applied to the tool
	VariationID *string `form:"variation_id,omitempty" json:"variation_id,omitempty" xml:"variation_id,omitempty"`
	// The name of the tool
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// Description of the tool
	Description *string `form:"description,omitempty" json:"description,omitempty" xml:"description,omitempty"`
	// Confirmation mode for the tool
	Confirm *string `form:"confirm,omitempty" json:"confirm,omitempty" xml:"confirm,omitempty"`
	// Prompt for the confirmation
	ConfirmPrompt *string `form:"confirm_prompt,omitempty" json:"confirm_prompt,omitempty" xml:"confirm_prompt,omitempty"`
	// Summarizer for the tool
	Summarizer *string `form:"summarizer,omitempty" json:"summarizer,omitempty" xml:"summarizer,omitempty"`
}

CanonicalToolAttributesResponseBody is used to define fields on response body types.

type Client

type Client struct {
	// ListTools Doer is the HTTP client used to make requests to the listTools
	// endpoint.
	ListToolsDoer goahttp.Doer

	// RestoreResponseBody controls whether the response bodies are reset after
	// decoding so they can be read again.
	RestoreResponseBody bool
	// contains filtered or unexported fields
}

Client lists the tools service endpoint HTTP clients.

func NewClient

func NewClient(
	scheme string,
	host string,
	doer goahttp.Doer,
	enc func(*http.Request) goahttp.Encoder,
	dec func(*http.Response) goahttp.Decoder,
	restoreBody bool,
) *Client

NewClient instantiates HTTP clients for all the tools service servers.

func (*Client) BuildListToolsRequest

func (c *Client) BuildListToolsRequest(ctx context.Context, v any) (*http.Request, error)

BuildListToolsRequest instantiates a HTTP request object with method and path set to call the "tools" service "listTools" endpoint

func (*Client) ListTools

func (c *Client) ListTools() goa.Endpoint

ListTools returns an endpoint that makes HTTP requests to the tools service listTools server.

type FunctionToolDefinitionResponseBody

type FunctionToolDefinitionResponseBody struct {
	// The ID of the deployment
	DeploymentID *string `form:"deployment_id,omitempty" json:"deployment_id,omitempty" xml:"deployment_id,omitempty"`
	// The ID of the asset
	AssetID *string `form:"asset_id,omitempty" json:"asset_id,omitempty" xml:"asset_id,omitempty"`
	// The ID of the function
	FunctionID *string `form:"function_id,omitempty" json:"function_id,omitempty" xml:"function_id,omitempty"`
	// Runtime environment (e.g., nodejs:22, python:3.12)
	Runtime *string `form:"runtime,omitempty" json:"runtime,omitempty" xml:"runtime,omitempty"`
	// Variables configuration for the function
	Variables any `form:"variables,omitempty" json:"variables,omitempty" xml:"variables,omitempty"`
	// Meta tags for the tool
	Meta map[string]string `form:"meta,omitempty" json:"meta,omitempty" xml:"meta,omitempty"`
	// The ID of the tool
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// The URN of this tool
	ToolUrn *string `form:"tool_urn,omitempty" json:"tool_urn,omitempty" xml:"tool_urn,omitempty"`
	// The ID of the project
	ProjectID *string `form:"project_id,omitempty" json:"project_id,omitempty" xml:"project_id,omitempty"`
	// The name of the tool
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// The canonical name of the tool. Will be the same as the name if there is no
	// variation.
	CanonicalName *string `form:"canonical_name,omitempty" json:"canonical_name,omitempty" xml:"canonical_name,omitempty"`
	// Description of the tool
	Description *string `form:"description,omitempty" json:"description,omitempty" xml:"description,omitempty"`
	// Version of the schema
	SchemaVersion *string `form:"schema_version,omitempty" json:"schema_version,omitempty" xml:"schema_version,omitempty"`
	// JSON schema for the request
	Schema *string `form:"schema,omitempty" json:"schema,omitempty" xml:"schema,omitempty"`
	// Confirmation mode for the tool
	Confirm *string `form:"confirm,omitempty" json:"confirm,omitempty" xml:"confirm,omitempty"`
	// Prompt for the confirmation
	ConfirmPrompt *string `form:"confirm_prompt,omitempty" json:"confirm_prompt,omitempty" xml:"confirm_prompt,omitempty"`
	// Summarizer for the tool
	Summarizer *string `form:"summarizer,omitempty" json:"summarizer,omitempty" xml:"summarizer,omitempty"`
	// The creation date of the tool.
	CreatedAt *string `form:"created_at,omitempty" json:"created_at,omitempty" xml:"created_at,omitempty"`
	// The last update date of the tool.
	UpdatedAt *string `form:"updated_at,omitempty" json:"updated_at,omitempty" xml:"updated_at,omitempty"`
	// The original details of a tool, excluding any variations
	Canonical *CanonicalToolAttributesResponseBody `form:"canonical,omitempty" json:"canonical,omitempty" xml:"canonical,omitempty"`
	// The variation details of a tool. Only includes explicitly varied fields.
	Variation *ToolVariationResponseBody `form:"variation,omitempty" json:"variation,omitempty" xml:"variation,omitempty"`
}

FunctionToolDefinitionResponseBody is used to define fields on response body types.

type HTTPToolDefinitionResponseBody

type HTTPToolDefinitionResponseBody struct {
	// The ID of the deployment
	DeploymentID *string `form:"deployment_id,omitempty" json:"deployment_id,omitempty" xml:"deployment_id,omitempty"`
	// The ID of the asset
	AssetID *string `form:"asset_id,omitempty" json:"asset_id,omitempty" xml:"asset_id,omitempty"`
	// Summary of the tool
	Summary *string `form:"summary,omitempty" json:"summary,omitempty" xml:"summary,omitempty"`
	// Response filter metadata for the tool
	ResponseFilter *ResponseFilterResponseBody `form:"response_filter,omitempty" json:"response_filter,omitempty" xml:"response_filter,omitempty"`
	// The ID of the OpenAPI v3 document
	Openapiv3DocumentID *string `form:"openapiv3_document_id,omitempty" json:"openapiv3_document_id,omitempty" xml:"openapiv3_document_id,omitempty"`
	// OpenAPI v3 operation
	Openapiv3Operation *string `form:"openapiv3_operation,omitempty" json:"openapiv3_operation,omitempty" xml:"openapiv3_operation,omitempty"`
	// The tags list for this http tool
	Tags []string `form:"tags,omitempty" json:"tags,omitempty" xml:"tags,omitempty"`
	// Security requirements for the underlying HTTP endpoint
	Security *string `form:"security,omitempty" json:"security,omitempty" xml:"security,omitempty"`
	// The default server URL for the tool
	DefaultServerURL *string `form:"default_server_url,omitempty" json:"default_server_url,omitempty" xml:"default_server_url,omitempty"`
	// HTTP method for the request
	HTTPMethod *string `form:"http_method,omitempty" json:"http_method,omitempty" xml:"http_method,omitempty"`
	// Path for the request
	Path *string `form:"path,omitempty" json:"path,omitempty" xml:"path,omitempty"`
	// The name of the source package
	PackageName *string `form:"package_name,omitempty" json:"package_name,omitempty" xml:"package_name,omitempty"`
	// The ID of the tool
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// The URN of this tool
	ToolUrn *string `form:"tool_urn,omitempty" json:"tool_urn,omitempty" xml:"tool_urn,omitempty"`
	// The ID of the project
	ProjectID *string `form:"project_id,omitempty" json:"project_id,omitempty" xml:"project_id,omitempty"`
	// The name of the tool
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// The canonical name of the tool. Will be the same as the name if there is no
	// variation.
	CanonicalName *string `form:"canonical_name,omitempty" json:"canonical_name,omitempty" xml:"canonical_name,omitempty"`
	// Description of the tool
	Description *string `form:"description,omitempty" json:"description,omitempty" xml:"description,omitempty"`
	// Version of the schema
	SchemaVersion *string `form:"schema_version,omitempty" json:"schema_version,omitempty" xml:"schema_version,omitempty"`
	// JSON schema for the request
	Schema *string `form:"schema,omitempty" json:"schema,omitempty" xml:"schema,omitempty"`
	// Confirmation mode for the tool
	Confirm *string `form:"confirm,omitempty" json:"confirm,omitempty" xml:"confirm,omitempty"`
	// Prompt for the confirmation
	ConfirmPrompt *string `form:"confirm_prompt,omitempty" json:"confirm_prompt,omitempty" xml:"confirm_prompt,omitempty"`
	// Summarizer for the tool
	Summarizer *string `form:"summarizer,omitempty" json:"summarizer,omitempty" xml:"summarizer,omitempty"`
	// The creation date of the tool.
	CreatedAt *string `form:"created_at,omitempty" json:"created_at,omitempty" xml:"created_at,omitempty"`
	// The last update date of the tool.
	UpdatedAt *string `form:"updated_at,omitempty" json:"updated_at,omitempty" xml:"updated_at,omitempty"`
	// The original details of a tool, excluding any variations
	Canonical *CanonicalToolAttributesResponseBody `form:"canonical,omitempty" json:"canonical,omitempty" xml:"canonical,omitempty"`
	// The variation details of a tool. Only includes explicitly varied fields.
	Variation *ToolVariationResponseBody `form:"variation,omitempty" json:"variation,omitempty" xml:"variation,omitempty"`
}

HTTPToolDefinitionResponseBody is used to define fields on response body types.

type ListToolsBadRequestResponseBody

type ListToolsBadRequestResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListToolsBadRequestResponseBody is the type of the "tools" service "listTools" endpoint HTTP response body for the "bad_request" error.

type ListToolsConflictResponseBody

type ListToolsConflictResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListToolsConflictResponseBody is the type of the "tools" service "listTools" endpoint HTTP response body for the "conflict" error.

type ListToolsForbiddenResponseBody

type ListToolsForbiddenResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListToolsForbiddenResponseBody is the type of the "tools" service "listTools" endpoint HTTP response body for the "forbidden" error.

type ListToolsGatewayErrorResponseBody

type ListToolsGatewayErrorResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListToolsGatewayErrorResponseBody is the type of the "tools" service "listTools" endpoint HTTP response body for the "gateway_error" error.

type ListToolsInvalidResponseBody

type ListToolsInvalidResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListToolsInvalidResponseBody is the type of the "tools" service "listTools" endpoint HTTP response body for the "invalid" error.

type ListToolsInvariantViolationResponseBody

type ListToolsInvariantViolationResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListToolsInvariantViolationResponseBody is the type of the "tools" service "listTools" endpoint HTTP response body for the "invariant_violation" error.

type ListToolsNotFoundResponseBody

type ListToolsNotFoundResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListToolsNotFoundResponseBody is the type of the "tools" service "listTools" endpoint HTTP response body for the "not_found" error.

type ListToolsResponseBody

type ListToolsResponseBody struct {
	// The cursor to fetch results from
	NextCursor *string `form:"next_cursor,omitempty" json:"next_cursor,omitempty" xml:"next_cursor,omitempty"`
	// The list of tools (polymorphic union of HTTP tools and prompt templates)
	Tools []*ToolResponseBody `form:"tools,omitempty" json:"tools,omitempty" xml:"tools,omitempty"`
}

ListToolsResponseBody is the type of the "tools" service "listTools" endpoint HTTP response body.

type ListToolsUnauthorizedResponseBody

type ListToolsUnauthorizedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListToolsUnauthorizedResponseBody is the type of the "tools" service "listTools" endpoint HTTP response body for the "unauthorized" error.

type ListToolsUnexpectedResponseBody

type ListToolsUnexpectedResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListToolsUnexpectedResponseBody is the type of the "tools" service "listTools" endpoint HTTP response body for the "unexpected" error.

type ListToolsUnsupportedMediaResponseBody

type ListToolsUnsupportedMediaResponseBody struct {
	// Name is the name of this class of errors.
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message *string `form:"message,omitempty" json:"message,omitempty" xml:"message,omitempty"`
	// Is the error temporary?
	Temporary *bool `form:"temporary,omitempty" json:"temporary,omitempty" xml:"temporary,omitempty"`
	// Is the error a timeout?
	Timeout *bool `form:"timeout,omitempty" json:"timeout,omitempty" xml:"timeout,omitempty"`
	// Is the error a server-side fault?
	Fault *bool `form:"fault,omitempty" json:"fault,omitempty" xml:"fault,omitempty"`
}

ListToolsUnsupportedMediaResponseBody is the type of the "tools" service "listTools" endpoint HTTP response body for the "unsupported_media" error.

type PromptTemplateResponseBody

type PromptTemplateResponseBody struct {
	// The revision tree ID for the prompt template
	HistoryID *string `form:"history_id,omitempty" json:"history_id,omitempty" xml:"history_id,omitempty"`
	// The previous version of the prompt template to use as predecessor
	PredecessorID *string `form:"predecessor_id,omitempty" json:"predecessor_id,omitempty" xml:"predecessor_id,omitempty"`
	// The template content
	Prompt *string `form:"prompt,omitempty" json:"prompt,omitempty" xml:"prompt,omitempty"`
	// The template engine
	Engine *string `form:"engine,omitempty" json:"engine,omitempty" xml:"engine,omitempty"`
	// The kind of prompt the template is used for
	Kind *string `form:"kind,omitempty" json:"kind,omitempty" xml:"kind,omitempty"`
	// The suggested tool names associated with the prompt template
	ToolsHint []string `form:"tools_hint,omitempty" json:"tools_hint,omitempty" xml:"tools_hint,omitempty"`
	// The suggested tool URNS associated with the prompt template
	ToolUrnsHint []string `form:"tool_urns_hint,omitempty" json:"tool_urns_hint,omitempty" xml:"tool_urns_hint,omitempty"`
	// The ID of the tool
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// The URN of this tool
	ToolUrn *string `form:"tool_urn,omitempty" json:"tool_urn,omitempty" xml:"tool_urn,omitempty"`
	// The ID of the project
	ProjectID *string `form:"project_id,omitempty" json:"project_id,omitempty" xml:"project_id,omitempty"`
	// The name of the tool
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// The canonical name of the tool. Will be the same as the name if there is no
	// variation.
	CanonicalName *string `form:"canonical_name,omitempty" json:"canonical_name,omitempty" xml:"canonical_name,omitempty"`
	// Description of the tool
	Description *string `form:"description,omitempty" json:"description,omitempty" xml:"description,omitempty"`
	// Version of the schema
	SchemaVersion *string `form:"schema_version,omitempty" json:"schema_version,omitempty" xml:"schema_version,omitempty"`
	// JSON schema for the request
	Schema *string `form:"schema,omitempty" json:"schema,omitempty" xml:"schema,omitempty"`
	// Confirmation mode for the tool
	Confirm *string `form:"confirm,omitempty" json:"confirm,omitempty" xml:"confirm,omitempty"`
	// Prompt for the confirmation
	ConfirmPrompt *string `form:"confirm_prompt,omitempty" json:"confirm_prompt,omitempty" xml:"confirm_prompt,omitempty"`
	// Summarizer for the tool
	Summarizer *string `form:"summarizer,omitempty" json:"summarizer,omitempty" xml:"summarizer,omitempty"`
	// The creation date of the tool.
	CreatedAt *string `form:"created_at,omitempty" json:"created_at,omitempty" xml:"created_at,omitempty"`
	// The last update date of the tool.
	UpdatedAt *string `form:"updated_at,omitempty" json:"updated_at,omitempty" xml:"updated_at,omitempty"`
	// The original details of a tool, excluding any variations
	Canonical *CanonicalToolAttributesResponseBody `form:"canonical,omitempty" json:"canonical,omitempty" xml:"canonical,omitempty"`
	// The variation details of a tool. Only includes explicitly varied fields.
	Variation *ToolVariationResponseBody `form:"variation,omitempty" json:"variation,omitempty" xml:"variation,omitempty"`
}

PromptTemplateResponseBody is used to define fields on response body types.

type ResponseFilterResponseBody

type ResponseFilterResponseBody struct {
	// Response filter type for the tool
	Type *string `form:"type,omitempty" json:"type,omitempty" xml:"type,omitempty"`
	// Status codes to filter for
	StatusCodes []string `form:"status_codes,omitempty" json:"status_codes,omitempty" xml:"status_codes,omitempty"`
	// Content types to filter for
	ContentTypes []string `form:"content_types,omitempty" json:"content_types,omitempty" xml:"content_types,omitempty"`
}

ResponseFilterResponseBody is used to define fields on response body types.

type ToolResponseBody

type ToolResponseBody struct {
	// The HTTP tool definition
	HTTPToolDefinition *HTTPToolDefinitionResponseBody `form:"http_tool_definition,omitempty" json:"http_tool_definition,omitempty" xml:"http_tool_definition,omitempty"`
	// The function tool definition
	FunctionToolDefinition *FunctionToolDefinitionResponseBody `form:"function_tool_definition,omitempty" json:"function_tool_definition,omitempty" xml:"function_tool_definition,omitempty"`
	// The prompt template
	PromptTemplate *PromptTemplateResponseBody `form:"prompt_template,omitempty" json:"prompt_template,omitempty" xml:"prompt_template,omitempty"`
}

ToolResponseBody is used to define fields on response body types.

type ToolVariationResponseBody

type ToolVariationResponseBody struct {
	// The ID of the tool variation
	ID *string `form:"id,omitempty" json:"id,omitempty" xml:"id,omitempty"`
	// The ID of the tool variation group
	GroupID *string `form:"group_id,omitempty" json:"group_id,omitempty" xml:"group_id,omitempty"`
	// The URN of the source tool
	SrcToolUrn *string `form:"src_tool_urn,omitempty" json:"src_tool_urn,omitempty" xml:"src_tool_urn,omitempty"`
	// The name of the source tool
	SrcToolName *string `form:"src_tool_name,omitempty" json:"src_tool_name,omitempty" xml:"src_tool_name,omitempty"`
	// The confirmation mode for the tool variation
	Confirm *string `form:"confirm,omitempty" json:"confirm,omitempty" xml:"confirm,omitempty"`
	// The confirmation prompt for the tool variation
	ConfirmPrompt *string `form:"confirm_prompt,omitempty" json:"confirm_prompt,omitempty" xml:"confirm_prompt,omitempty"`
	// The name of the tool variation
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// The description of the tool variation
	Description *string `form:"description,omitempty" json:"description,omitempty" xml:"description,omitempty"`
	// The summarizer of the tool variation
	Summarizer *string `form:"summarizer,omitempty" json:"summarizer,omitempty" xml:"summarizer,omitempty"`
	// The creation date of the tool variation
	CreatedAt *string `form:"created_at,omitempty" json:"created_at,omitempty" xml:"created_at,omitempty"`
	// The last update date of the tool variation
	UpdatedAt *string `form:"updated_at,omitempty" json:"updated_at,omitempty" xml:"updated_at,omitempty"`
}

ToolVariationResponseBody is used to define fields on response body types.

Jump to