server

package
v0.0.0-...-4ae6852 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2025 License: AGPL-3.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DecodeDeleteGlobalRequest

func DecodeDeleteGlobalRequest(mux goahttp.Muxer, decoder func(*http.Request) goahttp.Decoder) func(*http.Request) (*variations.DeleteGlobalPayload, error)

DecodeDeleteGlobalRequest returns a decoder for requests sent to the variations deleteGlobal endpoint.

func DecodeListGlobalRequest

func DecodeListGlobalRequest(mux goahttp.Muxer, decoder func(*http.Request) goahttp.Decoder) func(*http.Request) (*variations.ListGlobalPayload, error)

DecodeListGlobalRequest returns a decoder for requests sent to the variations listGlobal endpoint.

func DecodeUpsertGlobalRequest

func DecodeUpsertGlobalRequest(mux goahttp.Muxer, decoder func(*http.Request) goahttp.Decoder) func(*http.Request) (*variations.UpsertGlobalPayload, error)

DecodeUpsertGlobalRequest returns a decoder for requests sent to the variations upsertGlobal endpoint.

func DeleteGlobalVariationsPath

func DeleteGlobalVariationsPath() string

DeleteGlobalVariationsPath returns the URL path to the variations service deleteGlobal HTTP endpoint.

func EncodeDeleteGlobalError

func EncodeDeleteGlobalError(encoder func(context.Context, http.ResponseWriter) goahttp.Encoder, formatter func(ctx context.Context, err error) goahttp.Statuser) func(context.Context, http.ResponseWriter, error) error

EncodeDeleteGlobalError returns an encoder for errors returned by the deleteGlobal variations endpoint.

func EncodeDeleteGlobalResponse

func EncodeDeleteGlobalResponse(encoder func(context.Context, http.ResponseWriter) goahttp.Encoder) func(context.Context, http.ResponseWriter, any) error

EncodeDeleteGlobalResponse returns an encoder for responses returned by the variations deleteGlobal endpoint.

func EncodeListGlobalError

func EncodeListGlobalError(encoder func(context.Context, http.ResponseWriter) goahttp.Encoder, formatter func(ctx context.Context, err error) goahttp.Statuser) func(context.Context, http.ResponseWriter, error) error

EncodeListGlobalError returns an encoder for errors returned by the listGlobal variations endpoint.

func EncodeListGlobalResponse

func EncodeListGlobalResponse(encoder func(context.Context, http.ResponseWriter) goahttp.Encoder) func(context.Context, http.ResponseWriter, any) error

EncodeListGlobalResponse returns an encoder for responses returned by the variations listGlobal endpoint.

func EncodeUpsertGlobalError

func EncodeUpsertGlobalError(encoder func(context.Context, http.ResponseWriter) goahttp.Encoder, formatter func(ctx context.Context, err error) goahttp.Statuser) func(context.Context, http.ResponseWriter, error) error

EncodeUpsertGlobalError returns an encoder for errors returned by the upsertGlobal variations endpoint.

func EncodeUpsertGlobalResponse

func EncodeUpsertGlobalResponse(encoder func(context.Context, http.ResponseWriter) goahttp.Encoder) func(context.Context, http.ResponseWriter, any) error

EncodeUpsertGlobalResponse returns an encoder for responses returned by the variations upsertGlobal endpoint.

func ListGlobalVariationsPath

func ListGlobalVariationsPath() string

ListGlobalVariationsPath returns the URL path to the variations service listGlobal HTTP endpoint.

func Mount

func Mount(mux goahttp.Muxer, h *Server)

Mount configures the mux to serve the variations endpoints.

func MountDeleteGlobalHandler

func MountDeleteGlobalHandler(mux goahttp.Muxer, h http.Handler)

MountDeleteGlobalHandler configures the mux to serve the "variations" service "deleteGlobal" endpoint.

func MountListGlobalHandler

func MountListGlobalHandler(mux goahttp.Muxer, h http.Handler)

MountListGlobalHandler configures the mux to serve the "variations" service "listGlobal" endpoint.

func MountUpsertGlobalHandler

func MountUpsertGlobalHandler(mux goahttp.Muxer, h http.Handler)

MountUpsertGlobalHandler configures the mux to serve the "variations" service "upsertGlobal" endpoint.

func NewDeleteGlobalHandler

func NewDeleteGlobalHandler(
	endpoint goa.Endpoint,
	mux goahttp.Muxer,
	decoder func(*http.Request) goahttp.Decoder,
	encoder func(context.Context, http.ResponseWriter) goahttp.Encoder,
	errhandler func(context.Context, http.ResponseWriter, error),
	formatter func(ctx context.Context, err error) goahttp.Statuser,
) http.Handler

NewDeleteGlobalHandler creates a HTTP handler which loads the HTTP request and calls the "variations" service "deleteGlobal" endpoint.

func NewDeleteGlobalPayload

func NewDeleteGlobalPayload(variationID string, sessionToken *string, apikeyToken *string, projectSlugInput *string) *variations.DeleteGlobalPayload

NewDeleteGlobalPayload builds a variations service deleteGlobal endpoint payload.

func NewListGlobalHandler

func NewListGlobalHandler(
	endpoint goa.Endpoint,
	mux goahttp.Muxer,
	decoder func(*http.Request) goahttp.Decoder,
	encoder func(context.Context, http.ResponseWriter) goahttp.Encoder,
	errhandler func(context.Context, http.ResponseWriter, error),
	formatter func(ctx context.Context, err error) goahttp.Statuser,
) http.Handler

NewListGlobalHandler creates a HTTP handler which loads the HTTP request and calls the "variations" service "listGlobal" endpoint.

func NewListGlobalPayload

func NewListGlobalPayload(sessionToken *string, apikeyToken *string, projectSlugInput *string) *variations.ListGlobalPayload

NewListGlobalPayload builds a variations service listGlobal endpoint payload.

func NewUpsertGlobalHandler

func NewUpsertGlobalHandler(
	endpoint goa.Endpoint,
	mux goahttp.Muxer,
	decoder func(*http.Request) goahttp.Decoder,
	encoder func(context.Context, http.ResponseWriter) goahttp.Encoder,
	errhandler func(context.Context, http.ResponseWriter, error),
	formatter func(ctx context.Context, err error) goahttp.Statuser,
) http.Handler

NewUpsertGlobalHandler creates a HTTP handler which loads the HTTP request and calls the "variations" service "upsertGlobal" endpoint.

func NewUpsertGlobalPayload

func NewUpsertGlobalPayload(body *UpsertGlobalRequestBody, sessionToken *string, apikeyToken *string, projectSlugInput *string) *variations.UpsertGlobalPayload

NewUpsertGlobalPayload builds a variations service upsertGlobal endpoint payload.

func UpsertGlobalVariationsPath

func UpsertGlobalVariationsPath() string

UpsertGlobalVariationsPath returns the URL path to the variations service upsertGlobal HTTP endpoint.

func ValidateUpsertGlobalRequestBody

func ValidateUpsertGlobalRequestBody(body *UpsertGlobalRequestBody) (err error)

ValidateUpsertGlobalRequestBody runs the validations defined on UpsertGlobalRequestBody

Types

type DeleteGlobalBadRequestResponseBody

type DeleteGlobalBadRequestResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

DeleteGlobalBadRequestResponseBody is the type of the "variations" service "deleteGlobal" endpoint HTTP response body for the "bad_request" error.

func NewDeleteGlobalBadRequestResponseBody

func NewDeleteGlobalBadRequestResponseBody(res *goa.ServiceError) *DeleteGlobalBadRequestResponseBody

NewDeleteGlobalBadRequestResponseBody builds the HTTP response body from the result of the "deleteGlobal" endpoint of the "variations" service.

type DeleteGlobalConflictResponseBody

type DeleteGlobalConflictResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

DeleteGlobalConflictResponseBody is the type of the "variations" service "deleteGlobal" endpoint HTTP response body for the "conflict" error.

func NewDeleteGlobalConflictResponseBody

func NewDeleteGlobalConflictResponseBody(res *goa.ServiceError) *DeleteGlobalConflictResponseBody

NewDeleteGlobalConflictResponseBody builds the HTTP response body from the result of the "deleteGlobal" endpoint of the "variations" service.

type DeleteGlobalForbiddenResponseBody

type DeleteGlobalForbiddenResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

DeleteGlobalForbiddenResponseBody is the type of the "variations" service "deleteGlobal" endpoint HTTP response body for the "forbidden" error.

func NewDeleteGlobalForbiddenResponseBody

func NewDeleteGlobalForbiddenResponseBody(res *goa.ServiceError) *DeleteGlobalForbiddenResponseBody

NewDeleteGlobalForbiddenResponseBody builds the HTTP response body from the result of the "deleteGlobal" endpoint of the "variations" service.

type DeleteGlobalGatewayErrorResponseBody

type DeleteGlobalGatewayErrorResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

DeleteGlobalGatewayErrorResponseBody is the type of the "variations" service "deleteGlobal" endpoint HTTP response body for the "gateway_error" error.

func NewDeleteGlobalGatewayErrorResponseBody

func NewDeleteGlobalGatewayErrorResponseBody(res *goa.ServiceError) *DeleteGlobalGatewayErrorResponseBody

NewDeleteGlobalGatewayErrorResponseBody builds the HTTP response body from the result of the "deleteGlobal" endpoint of the "variations" service.

type DeleteGlobalInvalidResponseBody

type DeleteGlobalInvalidResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

DeleteGlobalInvalidResponseBody is the type of the "variations" service "deleteGlobal" endpoint HTTP response body for the "invalid" error.

func NewDeleteGlobalInvalidResponseBody

func NewDeleteGlobalInvalidResponseBody(res *goa.ServiceError) *DeleteGlobalInvalidResponseBody

NewDeleteGlobalInvalidResponseBody builds the HTTP response body from the result of the "deleteGlobal" endpoint of the "variations" service.

type DeleteGlobalInvariantViolationResponseBody

type DeleteGlobalInvariantViolationResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

DeleteGlobalInvariantViolationResponseBody is the type of the "variations" service "deleteGlobal" endpoint HTTP response body for the "invariant_violation" error.

func NewDeleteGlobalInvariantViolationResponseBody

func NewDeleteGlobalInvariantViolationResponseBody(res *goa.ServiceError) *DeleteGlobalInvariantViolationResponseBody

NewDeleteGlobalInvariantViolationResponseBody builds the HTTP response body from the result of the "deleteGlobal" endpoint of the "variations" service.

type DeleteGlobalNotFoundResponseBody

type DeleteGlobalNotFoundResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

DeleteGlobalNotFoundResponseBody is the type of the "variations" service "deleteGlobal" endpoint HTTP response body for the "not_found" error.

func NewDeleteGlobalNotFoundResponseBody

func NewDeleteGlobalNotFoundResponseBody(res *goa.ServiceError) *DeleteGlobalNotFoundResponseBody

NewDeleteGlobalNotFoundResponseBody builds the HTTP response body from the result of the "deleteGlobal" endpoint of the "variations" service.

type DeleteGlobalResponseBody

type DeleteGlobalResponseBody struct {
	// The ID of the variation that was deleted
	VariationID string `form:"variation_id" json:"variation_id" xml:"variation_id"`
}

DeleteGlobalResponseBody is the type of the "variations" service "deleteGlobal" endpoint HTTP response body.

func NewDeleteGlobalResponseBody

func NewDeleteGlobalResponseBody(res *variations.DeleteGlobalToolVariationResult) *DeleteGlobalResponseBody

NewDeleteGlobalResponseBody builds the HTTP response body from the result of the "deleteGlobal" endpoint of the "variations" service.

type DeleteGlobalUnauthorizedResponseBody

type DeleteGlobalUnauthorizedResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

DeleteGlobalUnauthorizedResponseBody is the type of the "variations" service "deleteGlobal" endpoint HTTP response body for the "unauthorized" error.

func NewDeleteGlobalUnauthorizedResponseBody

func NewDeleteGlobalUnauthorizedResponseBody(res *goa.ServiceError) *DeleteGlobalUnauthorizedResponseBody

NewDeleteGlobalUnauthorizedResponseBody builds the HTTP response body from the result of the "deleteGlobal" endpoint of the "variations" service.

type DeleteGlobalUnexpectedResponseBody

type DeleteGlobalUnexpectedResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

DeleteGlobalUnexpectedResponseBody is the type of the "variations" service "deleteGlobal" endpoint HTTP response body for the "unexpected" error.

func NewDeleteGlobalUnexpectedResponseBody

func NewDeleteGlobalUnexpectedResponseBody(res *goa.ServiceError) *DeleteGlobalUnexpectedResponseBody

NewDeleteGlobalUnexpectedResponseBody builds the HTTP response body from the result of the "deleteGlobal" endpoint of the "variations" service.

type DeleteGlobalUnsupportedMediaResponseBody

type DeleteGlobalUnsupportedMediaResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

DeleteGlobalUnsupportedMediaResponseBody is the type of the "variations" service "deleteGlobal" endpoint HTTP response body for the "unsupported_media" error.

func NewDeleteGlobalUnsupportedMediaResponseBody

func NewDeleteGlobalUnsupportedMediaResponseBody(res *goa.ServiceError) *DeleteGlobalUnsupportedMediaResponseBody

NewDeleteGlobalUnsupportedMediaResponseBody builds the HTTP response body from the result of the "deleteGlobal" endpoint of the "variations" service.

type ListGlobalBadRequestResponseBody

type ListGlobalBadRequestResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

ListGlobalBadRequestResponseBody is the type of the "variations" service "listGlobal" endpoint HTTP response body for the "bad_request" error.

func NewListGlobalBadRequestResponseBody

func NewListGlobalBadRequestResponseBody(res *goa.ServiceError) *ListGlobalBadRequestResponseBody

NewListGlobalBadRequestResponseBody builds the HTTP response body from the result of the "listGlobal" endpoint of the "variations" service.

type ListGlobalConflictResponseBody

type ListGlobalConflictResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

ListGlobalConflictResponseBody is the type of the "variations" service "listGlobal" endpoint HTTP response body for the "conflict" error.

func NewListGlobalConflictResponseBody

func NewListGlobalConflictResponseBody(res *goa.ServiceError) *ListGlobalConflictResponseBody

NewListGlobalConflictResponseBody builds the HTTP response body from the result of the "listGlobal" endpoint of the "variations" service.

type ListGlobalForbiddenResponseBody

type ListGlobalForbiddenResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

ListGlobalForbiddenResponseBody is the type of the "variations" service "listGlobal" endpoint HTTP response body for the "forbidden" error.

func NewListGlobalForbiddenResponseBody

func NewListGlobalForbiddenResponseBody(res *goa.ServiceError) *ListGlobalForbiddenResponseBody

NewListGlobalForbiddenResponseBody builds the HTTP response body from the result of the "listGlobal" endpoint of the "variations" service.

type ListGlobalGatewayErrorResponseBody

type ListGlobalGatewayErrorResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

ListGlobalGatewayErrorResponseBody is the type of the "variations" service "listGlobal" endpoint HTTP response body for the "gateway_error" error.

func NewListGlobalGatewayErrorResponseBody

func NewListGlobalGatewayErrorResponseBody(res *goa.ServiceError) *ListGlobalGatewayErrorResponseBody

NewListGlobalGatewayErrorResponseBody builds the HTTP response body from the result of the "listGlobal" endpoint of the "variations" service.

type ListGlobalInvalidResponseBody

type ListGlobalInvalidResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

ListGlobalInvalidResponseBody is the type of the "variations" service "listGlobal" endpoint HTTP response body for the "invalid" error.

func NewListGlobalInvalidResponseBody

func NewListGlobalInvalidResponseBody(res *goa.ServiceError) *ListGlobalInvalidResponseBody

NewListGlobalInvalidResponseBody builds the HTTP response body from the result of the "listGlobal" endpoint of the "variations" service.

type ListGlobalInvariantViolationResponseBody

type ListGlobalInvariantViolationResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

ListGlobalInvariantViolationResponseBody is the type of the "variations" service "listGlobal" endpoint HTTP response body for the "invariant_violation" error.

func NewListGlobalInvariantViolationResponseBody

func NewListGlobalInvariantViolationResponseBody(res *goa.ServiceError) *ListGlobalInvariantViolationResponseBody

NewListGlobalInvariantViolationResponseBody builds the HTTP response body from the result of the "listGlobal" endpoint of the "variations" service.

type ListGlobalNotFoundResponseBody

type ListGlobalNotFoundResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

ListGlobalNotFoundResponseBody is the type of the "variations" service "listGlobal" endpoint HTTP response body for the "not_found" error.

func NewListGlobalNotFoundResponseBody

func NewListGlobalNotFoundResponseBody(res *goa.ServiceError) *ListGlobalNotFoundResponseBody

NewListGlobalNotFoundResponseBody builds the HTTP response body from the result of the "listGlobal" endpoint of the "variations" service.

type ListGlobalResponseBody

type ListGlobalResponseBody struct {
	Variations []*ToolVariationResponseBody `form:"variations" json:"variations" xml:"variations"`
}

ListGlobalResponseBody is the type of the "variations" service "listGlobal" endpoint HTTP response body.

func NewListGlobalResponseBody

func NewListGlobalResponseBody(res *variations.ListVariationsResult) *ListGlobalResponseBody

NewListGlobalResponseBody builds the HTTP response body from the result of the "listGlobal" endpoint of the "variations" service.

type ListGlobalUnauthorizedResponseBody

type ListGlobalUnauthorizedResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

ListGlobalUnauthorizedResponseBody is the type of the "variations" service "listGlobal" endpoint HTTP response body for the "unauthorized" error.

func NewListGlobalUnauthorizedResponseBody

func NewListGlobalUnauthorizedResponseBody(res *goa.ServiceError) *ListGlobalUnauthorizedResponseBody

NewListGlobalUnauthorizedResponseBody builds the HTTP response body from the result of the "listGlobal" endpoint of the "variations" service.

type ListGlobalUnexpectedResponseBody

type ListGlobalUnexpectedResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

ListGlobalUnexpectedResponseBody is the type of the "variations" service "listGlobal" endpoint HTTP response body for the "unexpected" error.

func NewListGlobalUnexpectedResponseBody

func NewListGlobalUnexpectedResponseBody(res *goa.ServiceError) *ListGlobalUnexpectedResponseBody

NewListGlobalUnexpectedResponseBody builds the HTTP response body from the result of the "listGlobal" endpoint of the "variations" service.

type ListGlobalUnsupportedMediaResponseBody

type ListGlobalUnsupportedMediaResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

ListGlobalUnsupportedMediaResponseBody is the type of the "variations" service "listGlobal" endpoint HTTP response body for the "unsupported_media" error.

func NewListGlobalUnsupportedMediaResponseBody

func NewListGlobalUnsupportedMediaResponseBody(res *goa.ServiceError) *ListGlobalUnsupportedMediaResponseBody

NewListGlobalUnsupportedMediaResponseBody builds the HTTP response body from the result of the "listGlobal" endpoint of the "variations" service.

type MountPoint

type MountPoint struct {
	// Method is the name of the service method served by the mounted HTTP handler.
	Method string
	// Verb is the HTTP method used to match requests to the mounted handler.
	Verb string
	// Pattern is the HTTP request path pattern used to match requests to the
	// mounted handler.
	Pattern string
}

MountPoint holds information about the mounted endpoints.

type Server

type Server struct {
	Mounts       []*MountPoint
	UpsertGlobal http.Handler
	DeleteGlobal http.Handler
	ListGlobal   http.Handler
}

Server lists the variations service endpoint HTTP handlers.

func New

func New(
	e *variations.Endpoints,
	mux goahttp.Muxer,
	decoder func(*http.Request) goahttp.Decoder,
	encoder func(context.Context, http.ResponseWriter) goahttp.Encoder,
	errhandler func(context.Context, http.ResponseWriter, error),
	formatter func(ctx context.Context, err error) goahttp.Statuser,
) *Server

New instantiates HTTP handlers for all the variations service endpoints using the provided encoder and decoder. The handlers are mounted on the given mux using the HTTP verb and path defined in the design. errhandler is called whenever a response fails to be encoded. formatter is used to format errors returned by the service methods prior to encoding. Both errhandler and formatter are optional and can be nil.

func (*Server) MethodNames

func (s *Server) MethodNames() []string

MethodNames returns the methods served.

func (*Server) Mount

func (s *Server) Mount(mux goahttp.Muxer)

Mount configures the mux to serve the variations endpoints.

func (*Server) Service

func (s *Server) Service() string

Service returns the name of the service served.

func (*Server) Use

func (s *Server) Use(m func(http.Handler) http.Handler)

Use wraps the server handlers with the given middleware.

type ToolVariationResponseBody

type ToolVariationResponseBody struct {
	// The ID of the tool variation
	ID string `form:"id" json:"id" xml:"id"`
	// The ID of the tool variation group
	GroupID string `form:"group_id" json:"group_id" xml:"group_id"`
	// The URN of the source tool
	SrcToolUrn string `form:"src_tool_urn" json:"src_tool_urn" xml:"src_tool_urn"`
	// The name of the source tool
	SrcToolName string `form:"src_tool_name" json:"src_tool_name" xml:"src_tool_name"`
	// The confirmation mode for the tool variation
	Confirm *string `form:"confirm,omitempty" json:"confirm,omitempty" xml:"confirm,omitempty"`
	// The confirmation prompt for the tool variation
	ConfirmPrompt *string `form:"confirm_prompt,omitempty" json:"confirm_prompt,omitempty" xml:"confirm_prompt,omitempty"`
	// The name of the tool variation
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// The description of the tool variation
	Description *string `form:"description,omitempty" json:"description,omitempty" xml:"description,omitempty"`
	// The summarizer of the tool variation
	Summarizer *string `form:"summarizer,omitempty" json:"summarizer,omitempty" xml:"summarizer,omitempty"`
	// The creation date of the tool variation
	CreatedAt string `form:"created_at" json:"created_at" xml:"created_at"`
	// The last update date of the tool variation
	UpdatedAt string `form:"updated_at" json:"updated_at" xml:"updated_at"`
}

ToolVariationResponseBody is used to define fields on response body types.

type UpsertGlobalBadRequestResponseBody

type UpsertGlobalBadRequestResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

UpsertGlobalBadRequestResponseBody is the type of the "variations" service "upsertGlobal" endpoint HTTP response body for the "bad_request" error.

func NewUpsertGlobalBadRequestResponseBody

func NewUpsertGlobalBadRequestResponseBody(res *goa.ServiceError) *UpsertGlobalBadRequestResponseBody

NewUpsertGlobalBadRequestResponseBody builds the HTTP response body from the result of the "upsertGlobal" endpoint of the "variations" service.

type UpsertGlobalConflictResponseBody

type UpsertGlobalConflictResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

UpsertGlobalConflictResponseBody is the type of the "variations" service "upsertGlobal" endpoint HTTP response body for the "conflict" error.

func NewUpsertGlobalConflictResponseBody

func NewUpsertGlobalConflictResponseBody(res *goa.ServiceError) *UpsertGlobalConflictResponseBody

NewUpsertGlobalConflictResponseBody builds the HTTP response body from the result of the "upsertGlobal" endpoint of the "variations" service.

type UpsertGlobalForbiddenResponseBody

type UpsertGlobalForbiddenResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

UpsertGlobalForbiddenResponseBody is the type of the "variations" service "upsertGlobal" endpoint HTTP response body for the "forbidden" error.

func NewUpsertGlobalForbiddenResponseBody

func NewUpsertGlobalForbiddenResponseBody(res *goa.ServiceError) *UpsertGlobalForbiddenResponseBody

NewUpsertGlobalForbiddenResponseBody builds the HTTP response body from the result of the "upsertGlobal" endpoint of the "variations" service.

type UpsertGlobalGatewayErrorResponseBody

type UpsertGlobalGatewayErrorResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

UpsertGlobalGatewayErrorResponseBody is the type of the "variations" service "upsertGlobal" endpoint HTTP response body for the "gateway_error" error.

func NewUpsertGlobalGatewayErrorResponseBody

func NewUpsertGlobalGatewayErrorResponseBody(res *goa.ServiceError) *UpsertGlobalGatewayErrorResponseBody

NewUpsertGlobalGatewayErrorResponseBody builds the HTTP response body from the result of the "upsertGlobal" endpoint of the "variations" service.

type UpsertGlobalInvalidResponseBody

type UpsertGlobalInvalidResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

UpsertGlobalInvalidResponseBody is the type of the "variations" service "upsertGlobal" endpoint HTTP response body for the "invalid" error.

func NewUpsertGlobalInvalidResponseBody

func NewUpsertGlobalInvalidResponseBody(res *goa.ServiceError) *UpsertGlobalInvalidResponseBody

NewUpsertGlobalInvalidResponseBody builds the HTTP response body from the result of the "upsertGlobal" endpoint of the "variations" service.

type UpsertGlobalInvariantViolationResponseBody

type UpsertGlobalInvariantViolationResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

UpsertGlobalInvariantViolationResponseBody is the type of the "variations" service "upsertGlobal" endpoint HTTP response body for the "invariant_violation" error.

func NewUpsertGlobalInvariantViolationResponseBody

func NewUpsertGlobalInvariantViolationResponseBody(res *goa.ServiceError) *UpsertGlobalInvariantViolationResponseBody

NewUpsertGlobalInvariantViolationResponseBody builds the HTTP response body from the result of the "upsertGlobal" endpoint of the "variations" service.

type UpsertGlobalNotFoundResponseBody

type UpsertGlobalNotFoundResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

UpsertGlobalNotFoundResponseBody is the type of the "variations" service "upsertGlobal" endpoint HTTP response body for the "not_found" error.

func NewUpsertGlobalNotFoundResponseBody

func NewUpsertGlobalNotFoundResponseBody(res *goa.ServiceError) *UpsertGlobalNotFoundResponseBody

NewUpsertGlobalNotFoundResponseBody builds the HTTP response body from the result of the "upsertGlobal" endpoint of the "variations" service.

type UpsertGlobalRequestBody

type UpsertGlobalRequestBody struct {
	// The URN of the source tool
	SrcToolUrn *string `form:"src_tool_urn,omitempty" json:"src_tool_urn,omitempty" xml:"src_tool_urn,omitempty"`
	// The name of the source tool
	SrcToolName *string `form:"src_tool_name,omitempty" json:"src_tool_name,omitempty" xml:"src_tool_name,omitempty"`
	// The confirmation mode for the tool variation
	Confirm *string `form:"confirm,omitempty" json:"confirm,omitempty" xml:"confirm,omitempty"`
	// The confirmation prompt for the tool variation
	ConfirmPrompt *string `form:"confirm_prompt,omitempty" json:"confirm_prompt,omitempty" xml:"confirm_prompt,omitempty"`
	// The name of the tool variation
	Name *string `form:"name,omitempty" json:"name,omitempty" xml:"name,omitempty"`
	// The summary of the tool variation
	Summary *string `form:"summary,omitempty" json:"summary,omitempty" xml:"summary,omitempty"`
	// The description of the tool variation
	Description *string `form:"description,omitempty" json:"description,omitempty" xml:"description,omitempty"`
	// The tags of the tool variation
	Tags []string `form:"tags,omitempty" json:"tags,omitempty" xml:"tags,omitempty"`
	// The summarizer of the tool variation
	Summarizer *string `form:"summarizer,omitempty" json:"summarizer,omitempty" xml:"summarizer,omitempty"`
}

UpsertGlobalRequestBody is the type of the "variations" service "upsertGlobal" endpoint HTTP request body.

type UpsertGlobalResponseBody

type UpsertGlobalResponseBody struct {
	Variation *ToolVariationResponseBody `form:"variation" json:"variation" xml:"variation"`
}

UpsertGlobalResponseBody is the type of the "variations" service "upsertGlobal" endpoint HTTP response body.

func NewUpsertGlobalResponseBody

func NewUpsertGlobalResponseBody(res *variations.UpsertGlobalToolVariationResult) *UpsertGlobalResponseBody

NewUpsertGlobalResponseBody builds the HTTP response body from the result of the "upsertGlobal" endpoint of the "variations" service.

type UpsertGlobalUnauthorizedResponseBody

type UpsertGlobalUnauthorizedResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

UpsertGlobalUnauthorizedResponseBody is the type of the "variations" service "upsertGlobal" endpoint HTTP response body for the "unauthorized" error.

func NewUpsertGlobalUnauthorizedResponseBody

func NewUpsertGlobalUnauthorizedResponseBody(res *goa.ServiceError) *UpsertGlobalUnauthorizedResponseBody

NewUpsertGlobalUnauthorizedResponseBody builds the HTTP response body from the result of the "upsertGlobal" endpoint of the "variations" service.

type UpsertGlobalUnexpectedResponseBody

type UpsertGlobalUnexpectedResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

UpsertGlobalUnexpectedResponseBody is the type of the "variations" service "upsertGlobal" endpoint HTTP response body for the "unexpected" error.

func NewUpsertGlobalUnexpectedResponseBody

func NewUpsertGlobalUnexpectedResponseBody(res *goa.ServiceError) *UpsertGlobalUnexpectedResponseBody

NewUpsertGlobalUnexpectedResponseBody builds the HTTP response body from the result of the "upsertGlobal" endpoint of the "variations" service.

type UpsertGlobalUnsupportedMediaResponseBody

type UpsertGlobalUnsupportedMediaResponseBody struct {
	// Name is the name of this class of errors.
	Name string `form:"name" json:"name" xml:"name"`
	// ID is a unique identifier for this particular occurrence of the problem.
	ID string `form:"id" json:"id" xml:"id"`
	// Message is a human-readable explanation specific to this occurrence of the
	// problem.
	Message string `form:"message" json:"message" xml:"message"`
	// Is the error temporary?
	Temporary bool `form:"temporary" json:"temporary" xml:"temporary"`
	// Is the error a timeout?
	Timeout bool `form:"timeout" json:"timeout" xml:"timeout"`
	// Is the error a server-side fault?
	Fault bool `form:"fault" json:"fault" xml:"fault"`
}

UpsertGlobalUnsupportedMediaResponseBody is the type of the "variations" service "upsertGlobal" endpoint HTTP response body for the "unsupported_media" error.

func NewUpsertGlobalUnsupportedMediaResponseBody

func NewUpsertGlobalUnsupportedMediaResponseBody(res *goa.ServiceError) *UpsertGlobalUnsupportedMediaResponseBody

NewUpsertGlobalUnsupportedMediaResponseBody builds the HTTP response body from the result of the "upsertGlobal" endpoint of the "variations" service.

Jump to