resources

package
v0.0.0-...-4ae6852 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2025 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const APIName = "gram"

APIName is the name of the API as defined in the design.

const APIVersion = "0.0.1"

APIVersion is the version of the API as defined in the design.

const ServiceName = "resources"

ServiceName is the name of the service as defined in the design. This is the same value that is set in the endpoint request contexts under the ServiceKey key.

Variables

var MethodNames = [1]string{"listResources"}

MethodNames lists the service method names as defined in the design. These are the same values that are set in the endpoint request contexts under the MethodKey key.

Functions

func MakeBadRequest

func MakeBadRequest(err error) *goa.ServiceError

MakeBadRequest builds a goa.ServiceError from an error.

func MakeConflict

func MakeConflict(err error) *goa.ServiceError

MakeConflict builds a goa.ServiceError from an error.

func MakeForbidden

func MakeForbidden(err error) *goa.ServiceError

MakeForbidden builds a goa.ServiceError from an error.

func MakeGatewayError

func MakeGatewayError(err error) *goa.ServiceError

MakeGatewayError builds a goa.ServiceError from an error.

func MakeInvalid

func MakeInvalid(err error) *goa.ServiceError

MakeInvalid builds a goa.ServiceError from an error.

func MakeInvariantViolation

func MakeInvariantViolation(err error) *goa.ServiceError

MakeInvariantViolation builds a goa.ServiceError from an error.

func MakeNotFound

func MakeNotFound(err error) *goa.ServiceError

MakeNotFound builds a goa.ServiceError from an error.

func MakeUnauthorized

func MakeUnauthorized(err error) *goa.ServiceError

MakeUnauthorized builds a goa.ServiceError from an error.

func MakeUnexpected

func MakeUnexpected(err error) *goa.ServiceError

MakeUnexpected builds a goa.ServiceError from an error.

func MakeUnsupportedMedia

func MakeUnsupportedMedia(err error) *goa.ServiceError

MakeUnsupportedMedia builds a goa.ServiceError from an error.

func NewListResourcesEndpoint

func NewListResourcesEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint

NewListResourcesEndpoint returns an endpoint function that calls the method "listResources" of service "resources".

Types

type Auther

type Auther interface {
	// APIKeyAuth implements the authorization logic for the APIKey security scheme.
	APIKeyAuth(ctx context.Context, key string, schema *security.APIKeyScheme) (context.Context, error)
}

Auther defines the authorization functions to be implemented by the service.

type Client

type Client struct {
	ListResourcesEndpoint goa.Endpoint
}

Client is the "resources" service client.

func NewClient

func NewClient(listResources goa.Endpoint) *Client

NewClient initializes a "resources" service client given the endpoints.

func (*Client) ListResources

func (c *Client) ListResources(ctx context.Context, p *ListResourcesPayload) (res *ListResourcesResult, err error)

ListResources calls the "listResources" endpoint of the "resources" service. ListResources may return the following errors:

  • "unauthorized" (type *goa.ServiceError): unauthorized access
  • "forbidden" (type *goa.ServiceError): permission denied
  • "bad_request" (type *goa.ServiceError): request is invalid
  • "not_found" (type *goa.ServiceError): resource not found
  • "conflict" (type *goa.ServiceError): resource already exists
  • "unsupported_media" (type *goa.ServiceError): unsupported media type
  • "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
  • "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
  • "unexpected" (type *goa.ServiceError): an unexpected error occurred
  • "gateway_error" (type *goa.ServiceError): an unexpected error occurred
  • error: internal error

type Endpoints

type Endpoints struct {
	ListResources goa.Endpoint
}

Endpoints wraps the "resources" service endpoints.

func NewEndpoints

func NewEndpoints(s Service) *Endpoints

NewEndpoints wraps the methods of the "resources" service with endpoints.

func (*Endpoints) Use

func (e *Endpoints) Use(m func(goa.Endpoint) goa.Endpoint)

Use applies the given middleware to all the "resources" service endpoints.

type ListResourcesPayload

type ListResourcesPayload struct {
	SessionToken     *string
	ProjectSlugInput *string
	// The deployment ID. If unset, latest deployment will be used.
	DeploymentID *string
	// The cursor to fetch results from
	Cursor *string
	// The number of resources to return per page
	Limit *int32
}

ListResourcesPayload is the payload type of the resources service listResources method.

type ListResourcesResult

type ListResourcesResult struct {
	// The cursor to fetch results from
	NextCursor *string
	// The list of resources
	Resources []*types.Resource
}

ListResourcesResult is the result type of the resources service listResources method.

type Service

type Service interface {
	// List all resources for a project
	ListResources(context.Context, *ListResourcesPayload) (res *ListResourcesResult, err error)
}

Dashboard API for interacting with resources.

Jump to