Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var BaseResourceAttributes = Type("BaseResourceAttributes", func() {
Meta("struct:pkg:path", "types")
Meta("type:generate:force")
Description("Common attributes shared by all resource types")
Attribute("id", String, "The ID of the resource")
Attribute("resource_urn", String, "The URN of this resource")
Attribute("project_id", String, "The ID of the project")
Attribute("name", String, "The name of the resource")
Attribute("description", String, "Description of the resource")
Attribute("uri", String, "The URI of the resource")
Attribute("title", String, "Optional title for the resource")
Attribute("mime_type", String, "Optional MIME type of the resource")
Attribute("created_at", String, func() {
Description("The creation date of the resource.")
Format(FormatDateTime)
})
Attribute("updated_at", String, func() {
Description("The last update date of the resource.")
Format(FormatDateTime)
})
Required("id", "project_id", "name", "description", "uri", "resource_urn", "created_at", "updated_at")
})
BaseResourceAttributes contains common fields shared by all resource types
var BaseToolAttributes = Type("BaseToolAttributes", func() { Meta("struct:pkg:path", "types") Meta("type:generate:force") Description("Common attributes shared by all tool types") Attribute("id", String, "The ID of the tool") Attribute("tool_urn", String, "The URN of this tool") Attribute("project_id", String, "The ID of the project") Attribute("name", String, "The name of the tool") Attribute("canonical_name", String, "The canonical name of the tool. Will be the same as the name if there is no variation.") Attribute("description", String, "Description of the tool") Attribute("schema_version", String, "Version of the schema") Attribute("schema", String, "JSON schema for the request") Attribute("confirm", String, "Confirmation mode for the tool") Attribute("confirm_prompt", String, "Prompt for the confirmation") Attribute("summarizer", String, "Summarizer for the tool") Attribute("created_at", String, func() { Description("The creation date of the tool.") Format(FormatDateTime) }) Attribute("updated_at", String, func() { Description("The last update date of the tool.") Format(FormatDateTime) }) Attribute("canonical", CanonicalToolAttributes, "The original details of a tool, excluding any variations") Attribute("variation", ToolVariation, "The variation details of a tool. Only includes explicitly varied fields.") Required("id", "project_id", "name", "canonical_name", "description", "schema", "tool_urn", "created_at", "updated_at") })
BaseToolAttributes contains common fields shared by all tool types
var CanonicalToolAttributes = Type("CanonicalToolAttributes", func() {
Meta("struct:pkg:path", "types")
Description("The original details of a tool")
Required("variation_id", "name", "description")
Attribute("variation_id", String, "The ID of the variation that was applied to the tool")
Attribute("name", String, "The name of the tool")
Attribute("description", String, "Description of the tool")
Attribute("confirm", String, "Confirmation mode for the tool")
Attribute("confirm_prompt", String, "Prompt for the confirmation")
Attribute("summarizer", String, "Summarizer for the tool")
})
var Deployment = Type("Deployment", func() { Required("id", "created_at", "organization_id", "project_id", "user_id", "openapiv3_assets", "status", "packages", "openapiv3_tool_count", "functions_tool_count") Attribute("id", String, func() { Description("The ID to of the deployment.") Example("bc5f4a555e933e6861d12edba4c2d87ef6caf8e6") }) Attribute("organization_id", String, func() { Description("The ID of the organization that the deployment belongs to.") }) Attribute("project_id", String, func() { Description("The ID of the project that the deployment belongs to.") }) Attribute("user_id", String, func() { Description("The ID of the user that created the deployment.") }) Attribute("created_at", String, func() { Description("The creation date of the deployment.") Format(FormatDateTime) }) Attribute("status", String, func() { Description("The status of the deployment.") }) Attribute("idempotency_key", String, func() { Description("A unique identifier that will mitigate against duplicate deployments.") Example("01jqq0ajmb4qh9eppz48dejr2m") }) Attribute("github_repo", String, func() { Description("The github repository in the form of \"owner/repo\".") Example("speakeasyapi/gram") }) Attribute("github_pr", String, func() { Description("The github pull request that resulted in the deployment.") Example("1234") }) Attribute("github_sha", String, func() { Description("The commit hash that triggered the deployment.") Example("f33e693e9e12552043bc0ec5c37f1b8a9e076161") }) Attribute("external_id", String, func() { Description("The external ID to refer to the deployment. This can be a git commit hash for example.") Example("bc5f4a555e933e6861d12edba4c2d87ef6caf8e6") }) Attribute("external_url", String, func() { Description("The upstream URL a deployment can refer to. This can be a github url to a commit hash or pull request.") }) Attribute("cloned_from", String, func() { Description("The ID of the deployment that this deployment was cloned from.") Example("bc5f4a555e933e6861d12edba4c2d87ef6caf8e6") }) Attribute("openapiv3_tool_count", Int64, func() { Description("The number of tools in the deployment generated from OpenAPI documents.") }) Attribute("openapiv3_assets", ArrayOf(OpenAPIv3DeploymentAsset), func() { Description("The IDs, as returned from the assets upload service, to uploaded OpenAPI 3.x documents whose operations will become tool definitions.") }) Attribute("functions_tool_count", Int64, func() { Description("The number of tools in the deployment generated from OpenAPI documents.") }) Attribute("functions_assets", ArrayOf(DeploymentFunctions), func() { Description("The IDs, as returned from the assets upload service, to uploaded OpenAPI 3.x documents whose operations will become tool definitions.") }) Attribute("packages", ArrayOf(DeploymentPackage), func() { Description("The packages that were deployed.") }) Meta("struct:pkg:path", "types") })
var DeploymentFunctions = Type("DeploymentFunctions", func() { Required("id", "asset_id", "name", "slug", "runtime") Attribute("id", String, func() { Description("The ID of the deployment asset.") }) Attribute("asset_id", String, func() { Description("The ID of the uploaded asset.") }) Attribute("name", String, func() { Description("The name to give the document as it will be displayed in UIs.") }) Attribute("slug", Slug, func() { Description("The slug to give the document as it will be displayed in URLs.") }) Attribute("runtime", String, func() { Description("The runtime to use when executing functions.") }) Meta("struct:pkg:path", "types") })
var DeploymentPackage = Type("DeploymentPackage", func() {
Required("id", "name", "version")
Attribute("id", String, func() {
Description("The ID of the deployment package.")
})
Attribute("name", String, func() {
Description("The name of the package.")
})
Attribute("version", String, func() {
Description("The version of the package.")
})
Meta("struct:pkg:path", "types")
})
var Environment = Type("Environment", func() { Meta("struct:pkg:path", "types") Description("Model representing an environment") Attribute("id", String, "The ID of the environment") Attribute("organization_id", String, "The organization ID this environment belongs to") Attribute("project_id", String, "The project ID this environment belongs to") Attribute("name", String, "The name of the environment") Attribute("slug", Slug, "The slug identifier for the environment") Attribute("description", String, "The description of the environment") Attribute("entries", ArrayOf(EnvironmentEntry), "List of environment entries") Attribute("created_at", String, func() { Description("The creation date of the environment") Format(FormatDateTime) }) Attribute("updated_at", String, func() { Description("When the environment was last updated") Format(FormatDateTime) }) Required("id", "organization_id", "project_id", "name", "slug", "entries", "created_at", "updated_at") })
var EnvironmentEntry = Type("EnvironmentEntry", func() {
Meta("struct:pkg:path", "types")
Description("A single environment entry")
Attribute("name", String, "The name of the environment variable")
Attribute("value", String, "Redacted values of the environment variable")
Attribute("created_at", String, func() {
Description("The creation date of the environment entry")
Format(FormatDateTime)
})
Attribute("updated_at", String, func() {
Description("When the environment entry was last updated")
Format(FormatDateTime)
})
Required("name", "value", "created_at", "updated_at")
})
var ExternalOAuthServer = Type("ExternalOAuthServer", func() { Meta("struct:pkg:path", "types") Attribute("id", String, "The ID of the external OAuth server") Attribute("project_id", String, "The project ID this external OAuth server belongs to") Attribute("slug", Slug, "The slug of the external OAuth server") Attribute("metadata", Any, "The metadata for the external OAuth server") Attribute("created_at", String, func() { Description("When the external OAuth server was created.") Format(FormatDateTime) }) Attribute("updated_at", String, func() { Description("When the external OAuth server was last updated.") Format(FormatDateTime) }) Required("id", "project_id", "slug", "metadata", "created_at", "updated_at") })
var ExternalOAuthServerForm = Type("ExternalOAuthServerForm", func() { Meta("struct:pkg:path", "types") Attribute("slug", Slug, "The slug of the external OAuth server") Attribute("metadata", Any, "The metadata for the external OAuth server") Required("slug", "metadata") })
var FunctionEnvironmentVariable = Type("FunctionEnvironmentVariable", func() {
Meta("struct:pkg:path", "types")
Attribute("description", String, "Description of the function environment variable")
Attribute("name", String, "The environment variables")
Required("name")
})
var FunctionResourceDefinition = Type("FunctionResourceDefinition", func() { Meta("struct:pkg:path", "types") Description("A function resource") Extend(BaseResourceAttributes) Attribute("deployment_id", String, "The ID of the deployment") Attribute("function_id", String, "The ID of the function") Attribute("runtime", String, "Runtime environment (e.g., nodejs:22, python:3.12)") Attribute("variables", Any, "Variables configuration for the resource") Attribute("meta", MapOf(String, String), "Meta tags for the tool") Required("deployment_id", "function_id", "runtime") })
FunctionResourceDefinition represents a function-based resource with all its attributes
var FunctionToolDefinition = Type("FunctionToolDefinition", func() { Meta("struct:pkg:path", "types") Description("A function tool") Extend(BaseToolAttributes) Attribute("deployment_id", String, "The ID of the deployment") Attribute("asset_id", String, "The ID of the asset") Attribute("function_id", String, "The ID of the function") Attribute("runtime", String, "Runtime environment (e.g., nodejs:22, python:3.12)") Attribute("variables", Any, "Variables configuration for the function") Attribute("meta", MapOf(String, String), "Meta tags for the tool") Required("deployment_id", "asset_id", "function_id", "runtime") })
FunctionToolDefinition represents a function-based tool with all its attributes
var HTTPToolDefinition = Type("HTTPToolDefinition", func() { Meta("struct:pkg:path", "types") Description("An HTTP tool") Extend(BaseToolAttributes) Attribute("deployment_id", String, "The ID of the deployment") Attribute("asset_id", String, "The ID of the asset") Attribute("summary", String, "Summary of the tool") Attribute("response_filter", ResponseFilter, "Response filter metadata for the tool") Attribute("openapiv3_document_id", String, "The ID of the OpenAPI v3 document") Attribute("openapiv3_operation", String, "OpenAPI v3 operation") Attribute("tags", ArrayOf(String), "The tags list for this http tool") Attribute("security", String, "Security requirements for the underlying HTTP endpoint") Attribute("default_server_url", String, "The default server URL for the tool") Attribute("http_method", String, "HTTP method for the request") Attribute("path", String, "Path for the request") Attribute("package_name", String, "The name of the source package") Required("summary", "tags", "http_method", "path", "schema", "deployment_id", "asset_id") })
HTTPTool represents an HTTP tool with all its attributes
var OAuthProxyProvider = Type("OAuthProxyProvider", func() { Meta("struct:pkg:path", "types") Attribute("id", String, "The ID of the OAuth proxy provider") Attribute("slug", Slug, "The slug of the OAuth proxy provider") Attribute("authorization_endpoint", String, "The authorization endpoint URL") Attribute("token_endpoint", String, "The token endpoint URL") Attribute("scopes_supported", ArrayOf(String), "The OAuth scopes supported by this provider") Attribute("grant_types_supported", ArrayOf(String), "The grant types supported by this provider") Attribute("token_endpoint_auth_methods_supported", ArrayOf(String), "The token endpoint auth methods supported by this provider") Attribute("created_at", String, func() { Description("When the OAuth proxy provider was created.") Format(FormatDateTime) }) Attribute("updated_at", String, func() { Description("When the OAuth proxy provider was last updated.") Format(FormatDateTime) }) Required("id", "slug", "authorization_endpoint", "token_endpoint", "created_at", "updated_at") })
var OAuthProxyServer = Type("OAuthProxyServer", func() { Meta("struct:pkg:path", "types") Attribute("id", String, "The ID of the OAuth proxy server") Attribute("project_id", String, "The project ID this OAuth proxy server belongs to") Attribute("slug", Slug, "The slug of the OAuth proxy server") Attribute("oauth_proxy_providers", ArrayOf(OAuthProxyProvider), "The OAuth proxy providers for this server") Attribute("created_at", String, func() { Description("When the OAuth proxy server was created.") Format(FormatDateTime) }) Attribute("updated_at", String, func() { Description("When the OAuth proxy server was last updated.") Format(FormatDateTime) }) Required("id", "project_id", "slug", "created_at", "updated_at") })
var OpenAPIv3DeploymentAsset = Type("OpenAPIv3DeploymentAsset", func() { Required("id", "asset_id", "name", "slug") Attribute("id", String, func() { Description("The ID of the deployment asset.") }) Attribute("asset_id", String, func() { Description("The ID of the uploaded asset.") }) Attribute("name", String, func() { Description("The name to give the document as it will be displayed in UIs.") }) Attribute("slug", Slug, func() { Description("The slug to give the document as it will be displayed in URLs.") }) Meta("struct:pkg:path", "types") })
var OrganizationEntry = Type("OrganizationEntry", func() { Attribute("id", String) Attribute("name", String) Attribute("slug", String) Attribute("projects", ArrayOf(ProjectEntry)) Attribute("sso_connection_id", String) Attribute("user_workspace_slugs", ArrayOf(String)) Required("id", "name", "slug", "projects") })
var PackageVersion = Type("PackageVersion", func() {
Required("id", "package_id", "deployment_id", "visibility", "semver", "created_at")
Attribute("id", String, "The ID of the package version")
Attribute("package_id", String, "The ID of the package that the version belongs to")
Attribute("deployment_id", String, "The ID of the deployment that the version belongs to")
Attribute("visibility", String, "The visibility of the package version")
Attribute("semver", String, "The semantic version value")
Attribute("created_at", String, "The creation date of the package version", func() {
Format(FormatDateTime)
})
})
var Project = Type("Project", func() { Required("id", "name", "slug", "organization_id", "created_at", "updated_at") Attribute("id", String, "The ID of the project") Attribute("name", String, "The name of the project") Attribute("slug", Slug, "The slug of the project") Attribute("organization_id", String, "The ID of the organization that owns the project") Attribute("logo_asset_id", String, "The ID of the logo asset for the project") Attribute("created_at", String, func() { Description("The creation date of the project.") Format(FormatDateTime) }) Attribute("updated_at", String, func() { Description("The last update date of the project.") Format(FormatDateTime) }) })
var ProjectEntry = Type("ProjectEntry", func() { Attribute("id", String, "The ID of the project") Attribute("name", String, "The name of the project") Attribute("slug", Slug, "The slug of the project") Required("id", "name", "slug") })
var ProjectPackage = Type("Package", func() {
Required("id", "name", "project_id", "organization_id", "created_at", "updated_at")
Attribute("id", String, "The ID of the package")
Attribute("project_id", String, "The ID of the project that owns the package")
Attribute("organization_id", String, "The ID of the organization that owns the package")
Attribute("name", String, "The name of the package")
Attribute("title", String, "The title of the package")
Attribute("summary", String, "The summary of the package")
Attribute("description", String, "The description of the package. This contains HTML content.")
Attribute("description_raw", String, "The unsanitized, user-supplied description of the package. Limited markdown syntax is supported.")
Attribute("keywords", ArrayOf(String), "The keywords of the package")
Attribute("url", String, "External URL for the package owner")
Attribute("image_asset_id", String, "The asset ID of the image to show for this package")
Attribute("latest_version", String, "The latest version of the package")
Attribute("created_at", String, "The creation date of the package", func() {
Format(FormatDateTime)
})
Attribute("updated_at", String, "The last update date of the package", func() {
Format(FormatDateTime)
})
Attribute("deleted_at", String, "The deletion date of the package", func() {
Format(FormatDateTime)
})
})
var PromptTemplate = Type("PromptTemplate", func() { Required("id", "history_id", "name", "prompt", "engine", "kind", "tools_hint", "tool_urn", "created_at", "updated_at") Description("A prompt template") Extend(BaseToolAttributes) Attribute("history_id", String, "The revision tree ID for the prompt template") Attribute("predecessor_id", String, "The previous version of the prompt template to use as predecessor") Attribute("prompt", String, "The template content") Attribute("engine", String, func() { Description("The template engine") Enum("mustache") }) Attribute("kind", String, func() { Description("The kind of prompt the template is used for") Enum("prompt", "higher_order_tool") }) Attribute("tools_hint", ArrayOf(String), func() { Description("The suggested tool names associated with the prompt template") MaxLength(20) }) Attribute("tool_urns_hint", ArrayOf(String), func() { Description("The suggested tool URNS associated with the prompt template") MaxLength(20) }) })
var PromptTemplateEntry = Type("PromptTemplateEntry", func() { Required("id", "name") Attribute("id", String, "The ID of the prompt template") Attribute("name", Slug, "The name of the prompt template") Attribute("kind", String, "The kind of the prompt template") })
var Resource = Type("Resource", func() { Meta("struct:pkg:path", "types") Description("A polymorphic resource - currently only function resources are supported") Attribute("function_resource_definition", FunctionResourceDefinition, "The function resource definition") })
Resource is a discriminated union for different resource types.
var ResourceEntry = Type("ResourceEntry", func() { Meta("struct:pkg:path", "types") Attribute("type", String, func() { Enum(string(urn.ResourceKindFunction)) }) Attribute("id", String, "The ID of the resource") Attribute("resource_urn", String, "The URN of the resource") Attribute("name", String, "The name of the resource") Attribute("uri", String, "The uri of the resource") Required("type", "id", "name", "uri", "resource_urn") })
var ResponseFilter = Type("ResponseFilter", func() {
Meta("struct:pkg:path", "types")
Description("Response filter metadata for the tool")
Attribute("type", String, "Response filter type for the tool")
Required("type")
Attribute("status_codes", ArrayOf(String), "Status codes to filter for")
Required("status_codes")
Attribute("content_types", ArrayOf(String), "Content types to filter for")
Required("content_types")
})
var SecurityVariable = Type("SecurityVariable", func() {
Meta("struct:pkg:path", "types")
Attribute("type", String, "The type of security")
Attribute("name", String, "The name of the security scheme")
Attribute("in_placement", String, "Where the security token is placed")
Attribute("scheme", String, "The security scheme")
Attribute("bearer_format", String, "The bearer format")
Attribute("oauth_types", ArrayOf(String), "The OAuth types")
Attribute("oauth_flows", Bytes, "The OAuth flows")
Attribute("env_variables", ArrayOf(String), "The environment variables")
Required("name", "in_placement", "scheme", "env_variables")
})
var ServerVariable = Type("ServerVariable", func() {
Meta("struct:pkg:path", "types")
Attribute("description", String, "Description of the server variable")
Attribute("env_variables", ArrayOf(String), "The environment variables")
Required("description", "env_variables")
})
var Slug = Type("Slug", String, func() { Description("A short url-friendly label that uniquely identifies a resource.") Pattern(constants.SlugPattern) MaxLength(40) })
var Tool = Type("Tool", func() { Meta("struct:pkg:path", "types") Description("A polymorphic tool - can be an HTTP tool or a prompt template") Attribute("http_tool_definition", HTTPToolDefinition, "The HTTP tool definition") Attribute("function_tool_definition", FunctionToolDefinition, "The function tool definition") Attribute("prompt_template", PromptTemplate, "The prompt template") })
Tool is a discriminated union of HTTP tools and prompt templates. Custom JSON marshaling provided in goaext.
var ToolEntry = Type("ToolEntry", func() { Attribute("type", String, func() { Enum(string(urn.ToolKindHTTP), string(urn.ToolKindPrompt), string(urn.ToolKindFunction)) }) Attribute("id", String, "The ID of the tool") Attribute("tool_urn", String, "The URN of the tool") Attribute("name", String, "The name of the tool") Required("type", "id", "name", "tool_urn") })
var ToolVariation = Type("ToolVariation", func() {
Meta("struct:pkg:path", "types")
Attribute("id", String, "The ID of the tool variation")
Attribute("group_id", String, "The ID of the tool variation group")
Attribute("src_tool_urn", String, "The URN of the source tool")
Attribute("src_tool_name", String, "The name of the source tool")
Attribute("confirm", String, "The confirmation mode for the tool variation")
Attribute("confirm_prompt", String, "The confirmation prompt for the tool variation")
Attribute("name", String, "The name of the tool variation")
Attribute("description", String, "The description of the tool variation")
Attribute("summarizer", String, "The summarizer of the tool variation")
Attribute("created_at", String, "The creation date of the tool variation")
Attribute("updated_at", String, "The last update date of the tool variation")
Required("id", "group_id", "src_tool_name", "src_tool_urn", "created_at", "updated_at")
})
var Toolset = Type("Toolset", func() { Meta("struct:pkg:path", "types") Attribute("id", String, "The ID of the toolset") Attribute("project_id", String, "The project ID this toolset belongs to") Attribute("organization_id", String, "The organization ID this toolset belongs to") Attribute("account_type", String, "The account type of the organization") Attribute("name", String, "The name of the toolset") Attribute("slug", Slug, "The slug of the toolset") Attribute("description", String, "Description of the toolset") Attribute("default_environment_slug", Slug, "The slug of the environment to use as the default for the toolset") Attribute("security_variables", ArrayOf(SecurityVariable), "The security variables that are relevant to the toolset") Attribute("server_variables", ArrayOf(ServerVariable), "The server variables that are relevant to the toolset") Attribute("function_environment_variables", ArrayOf(FunctionEnvironmentVariable), "The function environment variables that are relevant to the toolset") Attribute("tools", ArrayOf(Tool), "The tools in this toolset") Attribute("tool_urns", ArrayOf(String), "The tool URNs in this toolset") Attribute("resources", ArrayOf(Resource), "The resources in this toolset") Attribute("resource_urns", ArrayOf(String), "The resource URNs in this toolset") Attribute("prompt_templates", ArrayOf(PromptTemplate), "The prompt templates in this toolset -- Note: these are actual prompts, as in MCP prompts") Attribute("mcp_slug", Slug, "The slug of the MCP to use for the toolset") Attribute("mcp_is_public", Boolean, "Whether the toolset is public in MCP") Attribute("mcp_enabled", Boolean, "Whether the toolset is enabled for MCP") Attribute("custom_domain_id", String, "The ID of the custom domain to use for the toolset") Attribute("external_oauth_server", ExternalOAuthServer, "The external OAuth server details") Attribute("oauth_proxy_server", OAuthProxyServer, "The OAuth proxy server details") Attribute("created_at", String, func() { Description("When the toolset was created.") Format(FormatDateTime) }) Attribute("updated_at", String, func() { Description("When the toolset was last updated.") Format(FormatDateTime) }) Required("id", "project_id", "organization_id", "account_type", "name", "slug", "tools", "prompt_templates", "tool_urns", "resources", "resource_urns", "created_at", "updated_at") })
var ToolsetEntry = Type("ToolsetEntry", func() { Meta("struct:pkg:path", "types") Attribute("id", String, "The ID of the toolset") Attribute("project_id", String, "The project ID this toolset belongs to") Attribute("organization_id", String, "The organization ID this toolset belongs to") Attribute("name", String, "The name of the toolset") Attribute("slug", Slug, "The slug of the toolset") Attribute("description", String, "Description of the toolset") Attribute("default_environment_slug", Slug, "The slug of the environment to use as the default for the toolset") Attribute("security_variables", ArrayOf(SecurityVariable), "The security variables that are relevant to the toolset") Attribute("server_variables", ArrayOf(ServerVariable), "The server variables that are relevant to the toolset") Attribute("function_environment_variables", ArrayOf(FunctionEnvironmentVariable), "The function environment variables that are relevant to the toolset") Attribute("tools", ArrayOf(ToolEntry), "The tools in this toolset") Attribute("tool_urns", ArrayOf(String), "The tool URNs in this toolset") Attribute("resources", ArrayOf(ResourceEntry), "The resources in this toolset") Attribute("resource_urns", ArrayOf(String), "The resource URNs in this toolset") Attribute("prompt_templates", ArrayOf(PromptTemplateEntry), "The prompt templates in this toolset -- Note: these are actual prompts, as in MCP prompts") Attribute("mcp_slug", Slug, "The slug of the MCP to use for the toolset") Attribute("mcp_is_public", Boolean, "Whether the toolset is public in MCP") Attribute("mcp_enabled", Boolean, "Whether the toolset is enabled for MCP") Attribute("custom_domain_id", String, "The ID of the custom domain to use for the toolset") Attribute("created_at", String, func() { Description("When the toolset was created.") Format(FormatDateTime) }) Attribute("updated_at", String, func() { Description("When the toolset was last updated.") Format(FormatDateTime) }) Required("id", "project_id", "organization_id", "name", "slug", "tools", "prompt_templates", "tool_urns", "resources", "resource_urns", "created_at", "updated_at") })
Functions ¶
func DeclareErrorResponses ¶
func DeclareErrorResponses()
DeclareErrorResponses declares the error responses at the service and method level including transport mappings (i.e. HTTP status codes).
Types ¶
This section is empty.