Documentation
¶
Index ¶
- func BuildReceiveWorkOSWebhookPayload(externalReceiveWorkOSWebhookWorkosSignature string) (*external.ReceiveWorkOSWebhookPayload, error)
- func BuildReceiveWorkOSWebhookStreamPayload(payload any, fpath string) (*external.ReceiveWorkOSWebhookRequestData, error)
- func DecodeReceiveWorkOSWebhookResponse(decoder func(*http.Response) goahttp.Decoder, restoreBody bool) func(*http.Response) (any, error)
- func EncodeReceiveWorkOSWebhookRequest(encoder func(*http.Request) goahttp.Encoder) func(*http.Request, any) error
- func ReceiveWorkOSWebhookExternalPath() string
- type Client
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildReceiveWorkOSWebhookPayload ¶
func BuildReceiveWorkOSWebhookPayload(externalReceiveWorkOSWebhookWorkosSignature string) (*external.ReceiveWorkOSWebhookPayload, error)
BuildReceiveWorkOSWebhookPayload builds the payload for the external receiveWorkOSWebhook endpoint from CLI flags.
func BuildReceiveWorkOSWebhookStreamPayload ¶
func BuildReceiveWorkOSWebhookStreamPayload(payload any, fpath string) (*external.ReceiveWorkOSWebhookRequestData, error)
// BuildReceiveWorkOSWebhookStreamPayload creates a streaming endpoint request payload from the method payload and the path to the file to be streamed
func DecodeReceiveWorkOSWebhookResponse ¶
func DecodeReceiveWorkOSWebhookResponse(decoder func(*http.Response) goahttp.Decoder, restoreBody bool) func(*http.Response) (any, error)
DecodeReceiveWorkOSWebhookResponse returns a decoder for responses returned by the external receiveWorkOSWebhook endpoint. restoreBody controls whether the response body should be restored after having been read.
func EncodeReceiveWorkOSWebhookRequest ¶
func EncodeReceiveWorkOSWebhookRequest(encoder func(*http.Request) goahttp.Encoder) func(*http.Request, any) error
EncodeReceiveWorkOSWebhookRequest returns an encoder for requests sent to the external receiveWorkOSWebhook server.
func ReceiveWorkOSWebhookExternalPath ¶
func ReceiveWorkOSWebhookExternalPath() string
ReceiveWorkOSWebhookExternalPath returns the URL path to the external service receiveWorkOSWebhook HTTP endpoint.
Types ¶
type Client ¶
type Client struct {
// ReceiveWorkOSWebhook Doer is the HTTP client used to make requests to the
// receiveWorkOSWebhook endpoint.
ReceiveWorkOSWebhookDoer goahttp.Doer
// RestoreResponseBody controls whether the response bodies are reset after
// decoding so they can be read again.
RestoreResponseBody bool
// contains filtered or unexported fields
}
Client lists the external service endpoint HTTP clients.
func NewClient ¶
func NewClient( scheme string, host string, doer goahttp.Doer, enc func(*http.Request) goahttp.Encoder, dec func(*http.Response) goahttp.Decoder, restoreBody bool, ) *Client
NewClient instantiates HTTP clients for all the external service servers.
func (*Client) BuildReceiveWorkOSWebhookRequest ¶
func (c *Client) BuildReceiveWorkOSWebhookRequest(ctx context.Context, v any) (*http.Request, error)
BuildReceiveWorkOSWebhookRequest instantiates a HTTP request object with method and path set to call the "external" service "receiveWorkOSWebhook" endpoint
func (*Client) ReceiveWorkOSWebhook ¶
ReceiveWorkOSWebhook returns an endpoint that makes HTTP requests to the external service receiveWorkOSWebhook server.