Documentation
¶
Index ¶
- Constants
- Variables
- func MakeBadRequest(err error) *goa.ServiceError
- func MakeConflict(err error) *goa.ServiceError
- func MakeForbidden(err error) *goa.ServiceError
- func MakeGatewayError(err error) *goa.ServiceError
- func MakeInvalid(err error) *goa.ServiceError
- func MakeInvariantViolation(err error) *goa.ServiceError
- func MakeNotFound(err error) *goa.ServiceError
- func MakeUnauthorized(err error) *goa.ServiceError
- func MakeUnexpected(err error) *goa.ServiceError
- func MakeUnsupportedMedia(err error) *goa.ServiceError
- func NewAddPluginServerEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewCreatePluginEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewDeletePluginEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewDownloadCodexInstallScriptEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewDownloadObservabilityPluginEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewDownloadPluginPackageEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewGetPluginEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewGetPublishStatusEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewListPluginsEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewPublishPluginsEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewRemovePluginServerEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewSetPluginAssignmentsEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewUpdatePluginEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- func NewUpdatePluginServerEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
- type AddPluginServerPayload
- type Auther
- type Client
- func (c *Client) AddPluginServer(ctx context.Context, p *AddPluginServerPayload) (res *PluginServer, err error)
- func (c *Client) CreatePlugin(ctx context.Context, p *CreatePluginPayload) (res *Plugin, err error)
- func (c *Client) DeletePlugin(ctx context.Context, p *DeletePluginPayload) (err error)
- func (c *Client) DownloadCodexInstallScript(ctx context.Context, p *DownloadCodexInstallScriptPayload) (res *DownloadCodexInstallScriptResult, resp io.ReadCloser, err error)
- func (c *Client) DownloadObservabilityPlugin(ctx context.Context, p *DownloadObservabilityPluginPayload) (res *DownloadObservabilityPluginResult, resp io.ReadCloser, err error)
- func (c *Client) DownloadPluginPackage(ctx context.Context, p *DownloadPluginPackagePayload) (res *DownloadPluginPackageResult, resp io.ReadCloser, err error)
- func (c *Client) GetPlugin(ctx context.Context, p *GetPluginPayload) (res *Plugin, err error)
- func (c *Client) GetPublishStatus(ctx context.Context, p *GetPublishStatusPayload) (res *PublishStatusResult, err error)
- func (c *Client) ListPlugins(ctx context.Context, p *ListPluginsPayload) (res *ListPluginsResult, err error)
- func (c *Client) PublishPlugins(ctx context.Context, p *PublishPluginsPayload) (res *PublishPluginsResult, err error)
- func (c *Client) RemovePluginServer(ctx context.Context, p *RemovePluginServerPayload) (err error)
- func (c *Client) SetPluginAssignments(ctx context.Context, p *SetPluginAssignmentsPayload) (res *SetPluginAssignmentsResult, err error)
- func (c *Client) UpdatePlugin(ctx context.Context, p *UpdatePluginPayload) (res *Plugin, err error)
- func (c *Client) UpdatePluginServer(ctx context.Context, p *UpdatePluginServerPayload) (res *PluginServer, err error)
- type CreatePluginPayload
- type DeletePluginPayload
- type DownloadCodexInstallScriptPayload
- type DownloadCodexInstallScriptResponseData
- type DownloadCodexInstallScriptResult
- type DownloadObservabilityPluginPayload
- type DownloadObservabilityPluginResponseData
- type DownloadObservabilityPluginResult
- type DownloadPluginPackagePayload
- type DownloadPluginPackageResponseData
- type DownloadPluginPackageResult
- type Endpoints
- type GetPluginPayload
- type GetPublishStatusPayload
- type ListPluginsPayload
- type ListPluginsResult
- type Plugin
- type PluginAssignment
- type PluginServer
- type PublishPluginsPayload
- type PublishPluginsResult
- type PublishStatusResult
- type RemovePluginServerPayload
- type Service
- type SetPluginAssignmentsPayload
- type SetPluginAssignmentsResult
- type UpdatePluginPayload
- type UpdatePluginServerPayload
Constants ¶
const APIName = "gram"
APIName is the name of the API as defined in the design.
const APIVersion = "0.0.1"
APIVersion is the version of the API as defined in the design.
const ServiceName = "plugins"
ServiceName is the name of the service as defined in the design. This is the same value that is set in the endpoint request contexts under the ServiceKey key.
Variables ¶
var MethodNames = [14]string{"listPlugins", "getPlugin", "createPlugin", "updatePlugin", "deletePlugin", "addPluginServer", "updatePluginServer", "removePluginServer", "setPluginAssignments", "downloadPluginPackage", "downloadObservabilityPlugin", "downloadCodexInstallScript", "getPublishStatus", "publishPlugins"}
MethodNames lists the service method names as defined in the design. These are the same values that are set in the endpoint request contexts under the MethodKey key.
Functions ¶
func MakeBadRequest ¶
func MakeBadRequest(err error) *goa.ServiceError
MakeBadRequest builds a goa.ServiceError from an error.
func MakeConflict ¶
func MakeConflict(err error) *goa.ServiceError
MakeConflict builds a goa.ServiceError from an error.
func MakeForbidden ¶
func MakeForbidden(err error) *goa.ServiceError
MakeForbidden builds a goa.ServiceError from an error.
func MakeGatewayError ¶
func MakeGatewayError(err error) *goa.ServiceError
MakeGatewayError builds a goa.ServiceError from an error.
func MakeInvalid ¶
func MakeInvalid(err error) *goa.ServiceError
MakeInvalid builds a goa.ServiceError from an error.
func MakeInvariantViolation ¶
func MakeInvariantViolation(err error) *goa.ServiceError
MakeInvariantViolation builds a goa.ServiceError from an error.
func MakeNotFound ¶
func MakeNotFound(err error) *goa.ServiceError
MakeNotFound builds a goa.ServiceError from an error.
func MakeUnauthorized ¶
func MakeUnauthorized(err error) *goa.ServiceError
MakeUnauthorized builds a goa.ServiceError from an error.
func MakeUnexpected ¶
func MakeUnexpected(err error) *goa.ServiceError
MakeUnexpected builds a goa.ServiceError from an error.
func MakeUnsupportedMedia ¶
func MakeUnsupportedMedia(err error) *goa.ServiceError
MakeUnsupportedMedia builds a goa.ServiceError from an error.
func NewAddPluginServerEndpoint ¶
func NewAddPluginServerEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewAddPluginServerEndpoint returns an endpoint function that calls the method "addPluginServer" of service "plugins".
func NewCreatePluginEndpoint ¶
func NewCreatePluginEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewCreatePluginEndpoint returns an endpoint function that calls the method "createPlugin" of service "plugins".
func NewDeletePluginEndpoint ¶
func NewDeletePluginEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewDeletePluginEndpoint returns an endpoint function that calls the method "deletePlugin" of service "plugins".
func NewDownloadCodexInstallScriptEndpoint ¶
func NewDownloadCodexInstallScriptEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewDownloadCodexInstallScriptEndpoint returns an endpoint function that calls the method "downloadCodexInstallScript" of service "plugins".
func NewDownloadObservabilityPluginEndpoint ¶
func NewDownloadObservabilityPluginEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewDownloadObservabilityPluginEndpoint returns an endpoint function that calls the method "downloadObservabilityPlugin" of service "plugins".
func NewDownloadPluginPackageEndpoint ¶
func NewDownloadPluginPackageEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewDownloadPluginPackageEndpoint returns an endpoint function that calls the method "downloadPluginPackage" of service "plugins".
func NewGetPluginEndpoint ¶
func NewGetPluginEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewGetPluginEndpoint returns an endpoint function that calls the method "getPlugin" of service "plugins".
func NewGetPublishStatusEndpoint ¶
func NewGetPublishStatusEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewGetPublishStatusEndpoint returns an endpoint function that calls the method "getPublishStatus" of service "plugins".
func NewListPluginsEndpoint ¶
func NewListPluginsEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewListPluginsEndpoint returns an endpoint function that calls the method "listPlugins" of service "plugins".
func NewPublishPluginsEndpoint ¶
func NewPublishPluginsEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewPublishPluginsEndpoint returns an endpoint function that calls the method "publishPlugins" of service "plugins".
func NewRemovePluginServerEndpoint ¶
func NewRemovePluginServerEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewRemovePluginServerEndpoint returns an endpoint function that calls the method "removePluginServer" of service "plugins".
func NewSetPluginAssignmentsEndpoint ¶
func NewSetPluginAssignmentsEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewSetPluginAssignmentsEndpoint returns an endpoint function that calls the method "setPluginAssignments" of service "plugins".
func NewUpdatePluginEndpoint ¶
func NewUpdatePluginEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewUpdatePluginEndpoint returns an endpoint function that calls the method "updatePlugin" of service "plugins".
func NewUpdatePluginServerEndpoint ¶
func NewUpdatePluginServerEndpoint(s Service, authAPIKeyFn security.AuthAPIKeyFunc) goa.Endpoint
NewUpdatePluginServerEndpoint returns an endpoint function that calls the method "updatePluginServer" of service "plugins".
Types ¶
type AddPluginServerPayload ¶
type AddPluginServerPayload struct {
SessionToken *string
ProjectSlugInput *string
PluginID string
// Gram toolset ID for the MCP server.
ToolsetID string
// Display name for the server.
DisplayName string
Policy string
SortOrder int32
}
AddPluginServerPayload is the payload type of the plugins service addPluginServer method.
type Auther ¶
type Auther interface {
// APIKeyAuth implements the authorization logic for the APIKey security scheme.
APIKeyAuth(ctx context.Context, key string, schema *security.APIKeyScheme) (context.Context, error)
}
Auther defines the authorization functions to be implemented by the service.
type Client ¶
type Client struct {
ListPluginsEndpoint goa.Endpoint
GetPluginEndpoint goa.Endpoint
CreatePluginEndpoint goa.Endpoint
UpdatePluginEndpoint goa.Endpoint
DeletePluginEndpoint goa.Endpoint
AddPluginServerEndpoint goa.Endpoint
UpdatePluginServerEndpoint goa.Endpoint
RemovePluginServerEndpoint goa.Endpoint
SetPluginAssignmentsEndpoint goa.Endpoint
DownloadPluginPackageEndpoint goa.Endpoint
DownloadObservabilityPluginEndpoint goa.Endpoint
DownloadCodexInstallScriptEndpoint goa.Endpoint
GetPublishStatusEndpoint goa.Endpoint
PublishPluginsEndpoint goa.Endpoint
}
Client is the "plugins" service client.
func NewClient ¶
func NewClient(listPlugins, getPlugin, createPlugin, updatePlugin, deletePlugin, addPluginServer, updatePluginServer, removePluginServer, setPluginAssignments, downloadPluginPackage, downloadObservabilityPlugin, downloadCodexInstallScript, getPublishStatus, publishPlugins goa.Endpoint) *Client
NewClient initializes a "plugins" service client given the endpoints.
func (*Client) AddPluginServer ¶
func (c *Client) AddPluginServer(ctx context.Context, p *AddPluginServerPayload) (res *PluginServer, err error)
AddPluginServer calls the "addPluginServer" endpoint of the "plugins" service. AddPluginServer may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) CreatePlugin ¶
CreatePlugin calls the "createPlugin" endpoint of the "plugins" service. CreatePlugin may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) DeletePlugin ¶
func (c *Client) DeletePlugin(ctx context.Context, p *DeletePluginPayload) (err error)
DeletePlugin calls the "deletePlugin" endpoint of the "plugins" service. DeletePlugin may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) DownloadCodexInstallScript ¶
func (c *Client) DownloadCodexInstallScript(ctx context.Context, p *DownloadCodexInstallScriptPayload) (res *DownloadCodexInstallScriptResult, resp io.ReadCloser, err error)
DownloadCodexInstallScript calls the "downloadCodexInstallScript" endpoint of the "plugins" service. DownloadCodexInstallScript may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) DownloadObservabilityPlugin ¶
func (c *Client) DownloadObservabilityPlugin(ctx context.Context, p *DownloadObservabilityPluginPayload) (res *DownloadObservabilityPluginResult, resp io.ReadCloser, err error)
DownloadObservabilityPlugin calls the "downloadObservabilityPlugin" endpoint of the "plugins" service. DownloadObservabilityPlugin may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) DownloadPluginPackage ¶
func (c *Client) DownloadPluginPackage(ctx context.Context, p *DownloadPluginPackagePayload) (res *DownloadPluginPackageResult, resp io.ReadCloser, err error)
DownloadPluginPackage calls the "downloadPluginPackage" endpoint of the "plugins" service. DownloadPluginPackage may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) GetPlugin ¶
GetPlugin calls the "getPlugin" endpoint of the "plugins" service. GetPlugin may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) GetPublishStatus ¶
func (c *Client) GetPublishStatus(ctx context.Context, p *GetPublishStatusPayload) (res *PublishStatusResult, err error)
GetPublishStatus calls the "getPublishStatus" endpoint of the "plugins" service. GetPublishStatus may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) ListPlugins ¶
func (c *Client) ListPlugins(ctx context.Context, p *ListPluginsPayload) (res *ListPluginsResult, err error)
ListPlugins calls the "listPlugins" endpoint of the "plugins" service. ListPlugins may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) PublishPlugins ¶
func (c *Client) PublishPlugins(ctx context.Context, p *PublishPluginsPayload) (res *PublishPluginsResult, err error)
PublishPlugins calls the "publishPlugins" endpoint of the "plugins" service. PublishPlugins may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) RemovePluginServer ¶
func (c *Client) RemovePluginServer(ctx context.Context, p *RemovePluginServerPayload) (err error)
RemovePluginServer calls the "removePluginServer" endpoint of the "plugins" service. RemovePluginServer may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) SetPluginAssignments ¶
func (c *Client) SetPluginAssignments(ctx context.Context, p *SetPluginAssignmentsPayload) (res *SetPluginAssignmentsResult, err error)
SetPluginAssignments calls the "setPluginAssignments" endpoint of the "plugins" service. SetPluginAssignments may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) UpdatePlugin ¶
UpdatePlugin calls the "updatePlugin" endpoint of the "plugins" service. UpdatePlugin may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
func (*Client) UpdatePluginServer ¶
func (c *Client) UpdatePluginServer(ctx context.Context, p *UpdatePluginServerPayload) (res *PluginServer, err error)
UpdatePluginServer calls the "updatePluginServer" endpoint of the "plugins" service. UpdatePluginServer may return the following errors:
- "unauthorized" (type *goa.ServiceError): unauthorized access
- "forbidden" (type *goa.ServiceError): permission denied
- "bad_request" (type *goa.ServiceError): request is invalid
- "not_found" (type *goa.ServiceError): resource not found
- "conflict" (type *goa.ServiceError): resource already exists
- "unsupported_media" (type *goa.ServiceError): unsupported media type
- "invalid" (type *goa.ServiceError): request contains one or more invalidation fields
- "invariant_violation" (type *goa.ServiceError): an unexpected error occurred
- "unexpected" (type *goa.ServiceError): an unexpected error occurred
- "gateway_error" (type *goa.ServiceError): an unexpected error occurred
- error: internal error
type CreatePluginPayload ¶
type CreatePluginPayload struct {
SessionToken *string
ProjectSlugInput *string
// Display name for the plugin.
Name string
// Optional URL-safe identifier. Auto-generated from name if omitted.
Slug *string
// Optional description.
Description *string
}
CreatePluginPayload is the payload type of the plugins service createPlugin method.
type DeletePluginPayload ¶
DeletePluginPayload is the payload type of the plugins service deletePlugin method.
type DownloadCodexInstallScriptPayload ¶
DownloadCodexInstallScriptPayload is the payload type of the plugins service downloadCodexInstallScript method.
type DownloadCodexInstallScriptResponseData ¶
type DownloadCodexInstallScriptResponseData struct {
// Result is the method result.
Result *DownloadCodexInstallScriptResult
// Body streams the HTTP response body.
Body io.ReadCloser
}
DownloadCodexInstallScriptResponseData holds both the result and the HTTP response body reader of the "downloadCodexInstallScript" method.
type DownloadCodexInstallScriptResult ¶
DownloadCodexInstallScriptResult is the result type of the plugins service downloadCodexInstallScript method.
type DownloadObservabilityPluginPayload ¶
type DownloadObservabilityPluginPayload struct {
// Target platform.
Platform string
SessionToken *string
ProjectSlugInput *string
}
DownloadObservabilityPluginPayload is the payload type of the plugins service downloadObservabilityPlugin method.
type DownloadObservabilityPluginResponseData ¶
type DownloadObservabilityPluginResponseData struct {
// Result is the method result.
Result *DownloadObservabilityPluginResult
// Body streams the HTTP response body.
Body io.ReadCloser
}
DownloadObservabilityPluginResponseData holds both the result and the HTTP response body reader of the "downloadObservabilityPlugin" method.
type DownloadObservabilityPluginResult ¶
DownloadObservabilityPluginResult is the result type of the plugins service downloadObservabilityPlugin method.
type DownloadPluginPackagePayload ¶
type DownloadPluginPackagePayload struct {
// The plugin to download.
PluginID string
// Target platform to download plugins for.
Platform string
SessionToken *string
ProjectSlugInput *string
}
DownloadPluginPackagePayload is the payload type of the plugins service downloadPluginPackage method.
type DownloadPluginPackageResponseData ¶
type DownloadPluginPackageResponseData struct {
// Result is the method result.
Result *DownloadPluginPackageResult
// Body streams the HTTP response body.
Body io.ReadCloser
}
DownloadPluginPackageResponseData holds both the result and the HTTP response body reader of the "downloadPluginPackage" method.
type DownloadPluginPackageResult ¶
DownloadPluginPackageResult is the result type of the plugins service downloadPluginPackage method.
type Endpoints ¶
type Endpoints struct {
ListPlugins goa.Endpoint
GetPlugin goa.Endpoint
CreatePlugin goa.Endpoint
UpdatePlugin goa.Endpoint
DeletePlugin goa.Endpoint
AddPluginServer goa.Endpoint
UpdatePluginServer goa.Endpoint
RemovePluginServer goa.Endpoint
SetPluginAssignments goa.Endpoint
DownloadPluginPackage goa.Endpoint
DownloadObservabilityPlugin goa.Endpoint
DownloadCodexInstallScript goa.Endpoint
GetPublishStatus goa.Endpoint
PublishPlugins goa.Endpoint
}
Endpoints wraps the "plugins" service endpoints.
func NewEndpoints ¶
NewEndpoints wraps the methods of the "plugins" service with endpoints.
type GetPluginPayload ¶
GetPluginPayload is the payload type of the plugins service getPlugin method.
type GetPublishStatusPayload ¶
GetPublishStatusPayload is the payload type of the plugins service getPublishStatus method.
type ListPluginsPayload ¶
ListPluginsPayload is the payload type of the plugins service listPlugins method.
type ListPluginsResult ¶
type ListPluginsResult struct {
// The plugins in the organization.
Plugins []*Plugin
}
ListPluginsResult is the result type of the plugins service listPlugins method.
type Plugin ¶
type Plugin struct {
// Unique plugin identifier.
ID string
// Display name.
Name string
// URL-safe identifier, unique per org.
Slug string
// Optional description.
Description *string
// Number of active servers in this plugin.
ServerCount *int64
// Number of role/user assignments.
AssignmentCount *int64
// Servers included in this plugin.
Servers []*PluginServer
// Role/user assignments.
Assignments []*PluginAssignment
CreatedAt string
UpdatedAt string
}
Plugin is the result type of the plugins service getPlugin method.
type PluginAssignment ¶
type PluginServer ¶
type PluginServer struct {
// Unique plugin server identifier.
ID string
// Gram toolset ID.
ToolsetID string
// Display name shown in generated plugin config.
DisplayName string
// Whether this server is required or optional.
Policy string
// Ordering within the plugin.
SortOrder int32
CreatedAt string
}
PluginServer is the result type of the plugins service addPluginServer method.
type PublishPluginsPayload ¶
type PublishPluginsPayload struct {
// GitHub usernames to add as collaborators on the repo.
GithubUsernames []string
SessionToken *string
ProjectSlugInput *string
}
PublishPluginsPayload is the payload type of the plugins service publishPlugins method.
type PublishPluginsResult ¶
type PublishPluginsResult struct {
// The URL of the published GitHub repository.
RepoURL string
}
PublishPluginsResult is the result type of the plugins service publishPlugins method.
type PublishStatusResult ¶
type PublishStatusResult struct {
// Whether GitHub publishing is configured on the server.
Configured bool
// Whether this project has a GitHub connection.
Connected bool
// GitHub repo owner, if connected.
RepoOwner *string
// GitHub repo name, if connected.
RepoName *string
// Full GitHub repository URL, if connected.
RepoURL *string
// Git-based Claude Code marketplace URL — the value to pass to `/plugin
// marketplace add` or set as the source URL in `extraKnownMarketplaces`.
// Present once a marketplace token has been minted, which happens
// automatically on the first publish.
MarketplaceURL *string
}
PublishStatusResult is the result type of the plugins service getPublishStatus method.
type RemovePluginServerPayload ¶
type RemovePluginServerPayload struct {
// The plugin server ID to remove.
ID string
PluginID string
SessionToken *string
ProjectSlugInput *string
}
RemovePluginServerPayload is the payload type of the plugins service removePluginServer method.
type Service ¶
type Service interface {
// List all plugins for the current project.
ListPlugins(context.Context, *ListPluginsPayload) (res *ListPluginsResult, err error)
// Get a plugin with its servers and assignments.
GetPlugin(context.Context, *GetPluginPayload) (res *Plugin, err error)
// Create a new plugin.
CreatePlugin(context.Context, *CreatePluginPayload) (res *Plugin, err error)
// Update plugin metadata.
UpdatePlugin(context.Context, *UpdatePluginPayload) (res *Plugin, err error)
// Delete a plugin.
DeletePlugin(context.Context, *DeletePluginPayload) (err error)
// Add an MCP server to a plugin.
AddPluginServer(context.Context, *AddPluginServerPayload) (res *PluginServer, err error)
// Update a server's configuration within a plugin.
UpdatePluginServer(context.Context, *UpdatePluginServerPayload) (res *PluginServer, err error)
// Remove a server from a plugin.
RemovePluginServer(context.Context, *RemovePluginServerPayload) (err error)
// Replace all assignments for a plugin with the given list of principal URNs.
SetPluginAssignments(context.Context, *SetPluginAssignmentsPayload) (res *SetPluginAssignmentsResult, err error)
// If body implements [io.WriterTo], that implementation will be used instead.
// Consider [goa.design/goa/v3/pkg.SkipResponseWriter] to adapt existing
// implementations.
DownloadPluginPackage(context.Context, *DownloadPluginPackagePayload) (res *DownloadPluginPackageResult, body io.ReadCloser, err error)
// If body implements [io.WriterTo], that implementation will be used instead.
// Consider [goa.design/goa/v3/pkg.SkipResponseWriter] to adapt existing
// implementations.
DownloadObservabilityPlugin(context.Context, *DownloadObservabilityPluginPayload) (res *DownloadObservabilityPluginResult, body io.ReadCloser, err error)
// If body implements [io.WriterTo], that implementation will be used instead.
// Consider [goa.design/goa/v3/pkg.SkipResponseWriter] to adapt existing
// implementations.
DownloadCodexInstallScript(context.Context, *DownloadCodexInstallScriptPayload) (res *DownloadCodexInstallScriptResult, body io.ReadCloser, err error)
// Check whether GitHub publishing is configured and connected for this project.
GetPublishStatus(context.Context, *GetPublishStatusPayload) (res *PublishStatusResult, err error)
// Generate and publish all plugin packages to a GitHub repository.
PublishPlugins(context.Context, *PublishPluginsPayload) (res *PublishPluginsResult, err error)
}
Manage distributable plugin bundles of MCP servers and hooks.
type SetPluginAssignmentsPayload ¶
type SetPluginAssignmentsPayload struct {
SessionToken *string
ProjectSlugInput *string
PluginID string
// List of principal URNs to assign.
PrincipalUrns []string
}
SetPluginAssignmentsPayload is the payload type of the plugins service setPluginAssignments method.
type SetPluginAssignmentsResult ¶
type SetPluginAssignmentsResult struct {
// The updated assignments.
Assignments []*PluginAssignment
}
SetPluginAssignmentsResult is the result type of the plugins service setPluginAssignments method.
type UpdatePluginPayload ¶
type UpdatePluginPayload struct {
SessionToken *string
ProjectSlugInput *string
ID string
// Updated display name.
Name string
// Updated slug.
Slug string
// Updated description.
Description *string
}
UpdatePluginPayload is the payload type of the plugins service updatePlugin method.